#
# WARNING: This file is automatically generated.
# Any changes made here will be mercilessly lost.
#
# You have been warned, infidel.
#
# P.S. For the real source to this file, see:
#
#    ..../src/pre.in/MQSeries/Message/Accounting.in
#
# and for the evil hackery used to generate this, see:
#
#    ..../src/util/flatten_macros
#
# (c) 1999-2012 Morgan Stanley & Co. Incorporated
# See ..../src/LICENSE for terms of distribution.
#
package MQSeries::Message::Accounting;

#
# errata:
#
# http://publib.boulder.ibm.com/infocenter/wmqv7/v7r0/topic/com.ibm.mq.csqzax.doc/mo13570_.htm
#   page says MQCAMO_CONNECTION_NAME
#   cmqcfc.h says MQCACH_CONNECTION_NAME
#
# http://publib.boulder.ibm.com/infocenter/wmqv7/v7r0/topic/com.ibm.mq.csqzax.doc/mo13590_.htm
#   page does not list MQIAMO_GENERATED_MSGS (aka GeneratedMsgs)
#
# http://publib.boulder.ibm.com/infocenter/wmqv7/v7r0/topic/com.ibm.mq.csqzax.doc/mo13590_.htm
#   page says QDefinitionType but we use DefinitionType for consistency
#
# http://publib.boulder.ibm.com/infocenter/wmqv7/v7r0/topic/com.ibm.mq.csqzax.doc/mo13570_.htm
#  page says ConnName but we use ConnectionName for consistency
#

%ResponseParameters =
  (
   7006                                  => "ConnectionId",
   3024                                  => "ApplicationName",
   3025                                  => "UserId",
   3501                                  => "ChannelName",
   3506                                  => "ConnectionName",
   2701                                  => "CloseDate",
   2702                                  => "CloseTime",
   2703                                  => "ConnDate",
   2704                                  => "ConnTime",
   2705                                  => "DiscDate",
   2706                                  => "DiscTime",
   2707                                  => "IntervalEndDate",
   2708                                  => "IntervalEndTime",
   2709                                  => "OpenDate",
   2710                                  => "OpenTime",
   2711                                  => "IntervalStartDate",
   2712                                  => "IntervalStartTime",
   2004                                  => "CreateDate",
   2005                                  => "CreateTime",
   2015                                  => "QueueManager",
   2016                                  => "QName",
   8010                                  => "QAccountingData",
   1024                                  => "ApplicationPid",
   1079                                  => "SeqNumber",
   1025                                  => "ApplicationTid",
   745                                   => "BrowseBytes",
   747                                   => "GetBytes",
   748                                   => "PutBytes",
   783                                   => "PutTopicBytes",
   704                                   => "BackCount",
   705                                   => "BrowseCount",
   708                                   => "BrowseFailCount",
   706                                   => "BrowseMaxBytes",
   707                                   => "BrowseMinBytes",
   769                                   => "CBCount",
   770                                   => "CBFailCount",
   709                                   => "CloseCount",
   757                                   => "CloseFailCount",
   710                                   => "CommitCount",
   711                                   => "CommitFailCount",
   771                                   => "CtlCount",
   772                                   => "CtlFailCount",
   716                                   => "DiscType",
   721                                   => "GeneratedMsgs",
   722                                   => "GetCount",
   725                                   => "GetFailCount",
   723                                   => "GetMaxBytes",
   724                                   => "GetMinBytes",
   727                                   => "InqCount",
   752                                   => "InqFailCount",
   732                                   => "ObjectCount",
   733                                   => "OpenCount",
   751                                   => "OpenFailCount",
   734                                   => "Put1Count",
   755                                   => "Put1FailCount",
   735                                   => "PutCount",
   754                                   => "PutFailCount",
   736                                   => "PutMaxBytes",
   737                                   => "PutMinBytes",
   741                                   => "TimeOnQAvg",
   742                                   => "TimeOnQMax",
   743                                   => "TimeOnQMin",
   744                                   => "SetCount",
   753                                   => "SetFailCount",
   773                                   => "StatCount",
   774                                   => "StatFailCount",
   767                                   => "SubRqCount",
   768                                   => "SubRqFailCount",
   764                                   => "SubCountDur",
   766                                   => "SubFailCount",
   765                                   => "SubCountNDur",
   781                                   => "Put1TopicCount",
   782                                   => "Put1TopicFailCount",
   779                                   => "PutTopicCount",
   780                                   => "PutTopicFailCount",
   786                                   => "UnsubCountDur",
   788                                   => "UnsubFailCount",
   787                                   => "UnsubCountNDur",
   31                                    => "CommandLevel",
   7                                     => [ "DefinitionType", {
       2                                     => "Permanent",
       1                                     => "Predefined",
       3                                     => "Temporary",
       }, ],
   20                                    => [ "QType", {
       3                                     => "Alias",
       7                                     => "Cluster",
       1                                     => "Local",
       2                                     => "Model",
       6                                     => "Remote",
       }, ],
  );

1;
