#
# WARNING: This file is automatically generated.
# Any changes made here will be mercilessly lost.
#
# You have been warned, infidel.
#
# P.S. For the real source to this file, see:
#
#    ..../src/pre.in/MQSeries/Message/Statistics.in
#
# and for the evil hackery used to generate this, see:
#
#    ..../src/util/flatten_macros
#
# (c) 1999-2012 Morgan Stanley & Co. Incorporated
# See ..../src/LICENSE for terms of distribution.
#
package MQSeries::Message::Statistics;

#
# errata:
#
# http://publib.boulder.ibm.com/infocenter/wmqv7/v7r0/topic/com.ibm.mq.csqzax.doc/mo13650_.htm
#   page says MQIAMO_AVG_BATCHE_SIZE
#   cmqcfc.h says MQIAMO_AVG_BATCH_SIZE
#
# http://publib.boulder.ibm.com/infocenter/wmqv7/v7r0/topic/com.ibm.mq.csqzax.doc/mo13610_.htm
#   page says MQIAMO_PUBLISH_MSG_BYTES
#   cmqcfc.h says MQIAMO64_PUBLISH_MSG_BYTES
#
# http://publib.boulder.ibm.com/infocenter/wmqv7/v7r0/topic/com.ibm.mq.csqzax.doc/mo13630_.htm
#   page does not list MQIAMO_GENERATED_MSGS (aka GeneratedMsgs)
#
# http://publib.boulder.ibm.com/infocenter/wmqv7/v7r0/topic/com.ibm.mq.csqzax.doc/mo13630_.htm
#   page says QDefinitionType but we use DefinitionType for consistency
#
# http://publib.boulder.ibm.com/infocenter/wmqv7/v7r0/topic/com.ibm.mq.csqzax.doc/mo13610_.htm
#   page says "Description: MQIAMO_UNSUBS_FAILED" and "Identifier:
#   MQIAMO_UNSUBS_NDUR".  you figure it out.
#
# http://publib.boulder.ibm.com/infocenter/wmqv7/v7r0/topic/com.ibm.mq.csqzax.doc/mo13610_.htm
#   page says nothing about MQIAMO_SUBRQS, but a v7 qmgr sends them to
#   me
#

%ResponseParameters =
  (
   3501                                  => "ChannelName",
   3506                                  => "ConnectionName",
   2707                                  => "IntervalEndDate",
   2708                                  => "IntervalEndTime",
   2711                                  => "IntervalStartDate",
   2712                                  => "IntervalStartTime",
   2004                                  => "CreateDate",
   2005                                  => "CreateTime",
   2015                                  => "QueueManager",
   2016                                  => "QName",
   2017                                  => "RemoteQMgrName",
   8012                                  => "ChlStatisticsData",
   8011                                  => "QStatisticsData",
   1511                                  => [ "ChannelType", {
       6                                     => "Clntconn",
       8                                     => "ClusterReceiver",
       9                                     => "ClusterSender",
       3                                     => "Receiver",
       4                                     => "Requester",
       1                                     => "Sender",
       2                                     => "Server",
       7                                     => "Svrconn",
       }, ],
   745                                   => "BrowseBytes",
   746                                   => "TotalBytes",
   747                                   => "GetBytes",
   785                                   => "PublishMsgBytes",
   748                                   => "PutBytes",
   783                                   => "PutTopicBytes",
   702                                   => "AverageBatchSize",
   703                                   => "AvgTimeOnQ",
   704                                   => "BackCount",
   705                                   => "BrowseCount",
   708                                   => "BrowseFailCount",
   769                                   => "CBCount",
   770                                   => "CBFailCount",
   709                                   => "CloseCount",
   757                                   => "CloseFailCount",
   710                                   => "CommitCount",
   711                                   => "CommitFailCount",
   712                                   => "ConnCount",
   749                                   => "ConnFailCount",
   713                                   => "ConnsMax",
   771                                   => "CtlCount",
   772                                   => "CtlFailCount",
   714                                   => "DiscCount",
   717                                   => "ExitTimeAvg",
   718                                   => "ExitTimeMax",
   719                                   => "ExitTimeMin",
   720                                   => "FullBatchCount",
   721                                   => "GeneratedMsgs",
   722                                   => "GetCount",
   725                                   => "GetFailCount",
   726                                   => "IncmplBatchCount",
   727                                   => "InqCount",
   752                                   => "InqFailCount",
   728                                   => "MsgCount",
   758                                   => "ExpiredMsgCount",
   759                                   => "NonQueuedMsgCount",
   760                                   => "PurgeCount",
   729                                   => "NetTimeAvg",
   730                                   => "NetTimeMax",
   731                                   => "NetTimeMin",
   732                                   => "ObjectCount",
   733                                   => "OpenCount",
   751                                   => "OpenFailCount",
   784                                   => "PublishMsgCount",
   734                                   => "Put1Count",
   755                                   => "Put1FailCount",
   735                                   => "PutCount",
   754                                   => "PutFailCount",
   738                                   => "PutRetryCount",
   739                                   => "QMaxDepth",
   740                                   => "QMinDepth",
   744                                   => "SetCount",
   753                                   => "SetFailCount",
   773                                   => "StatCount",
   774                                   => "StatFailCount",
   767                                   => "SubRqCount",
   768                                   => "SubRqFailCount",
   764                                   => "SubCountDur",
   766                                   => "SubFailCount",
   765                                   => "SubCountNDur",
   775                                   => "SubCountDurHighWater",
   776                                   => "SubCountDurLowWater",
   777                                   => "SubCountNDurHighWater",
   778                                   => "SubCountNDurLowWater",
   781                                   => "Put1TopicCount",
   782                                   => "Put1TopicFailCount",
   779                                   => "PutTopicCount",
   780                                   => "PutTopicFailCount",
   786                                   => "UnsubCountDur",
   788                                   => "UnsubFailCount",
   787                                   => "UnsubCountNDur",
   31                                    => "CommandLevel",
   7                                     => [ "DefinitionType", {
       2                                     => "Permanent",
       1                                     => "Predefined",
       3                                     => "Temporary",
       }, ],
   20                                    => [ "QType", {
       3                                     => "Alias",
       7                                     => "Cluster",
       1                                     => "Local",
       2                                     => "Model",
       6                                     => "Remote",
       }, ],
  );

1;
