#
# WARNING: This file is automatically generated.
# Any changes made here will be mercilessly lost.
#
# You have been warned, infidel.
#
# P.S. For the real source to this file, see:
#
#    ..../src/pre.in/MQSeries/Command/PCF/ResponseParameters.in
#
# and for the evil hackery used to generate this, see:
#
#    ..../src/util/flatten_macros
#
# (c) 1999-2012 Morgan Stanley & Co. Incorporated
# See ..../src/LICENSE for terms of distribution.
#
package MQSeries::Command::PCF;

%ResponseParameters =
  (
   Error =>
   {
    ErrorId			=> [ 1013,             			3 ],
    ErrorOffset			=> [ 1018,                 		3 ],
    ParameterId			=> [ 1012,                 		3 ],
    Selector			=> [ 1014,             			3 ],
    CodedCharSetId		=> [ 2,                       		3 ],
    ResponseId			=> [ 7004,                		9                   ],
    ResponseQMgrName		=> [ 3070,                        	4 ],
   },

   QueueManager =>
   {
    AccountingConnOverride	=> [ 136,                            	3,],
    AccountingInterval		=> [ 135,                       		3 ],
    ActivityRecording		=> [ 138,                      		3,		$ResponseValues{ActivityRecording} ],
    ActivityConnOverride	=> [ 239,                          	3 ],
    ActivityTrace		=> [ 240,                  		3 ],

    AdoptNewMCACheck		=> [ 102,                     		3,		$ResponseValues{AdoptNewMCACheck} ],
    AdoptNewMCAType		=> [ 103,                    		3,		$ResponseValues{AdoptNewMCAType}  ],
    AlterationDate		=> [ 2027,                  		4 ],
    AlterationTime		=> [ 2028,                  		4 ],
    BridgeEvent			=> [ 74,                 		3 ],
    ChlAuthRecords		=> [ 248,                   		3 ],
    CFConlos			=> [ 245,                 		3,		$ResponseValues{CFConlos} ],
    CreationDate		=> [ 2004,                		4 ],
    CreationTime		=> [ 2005,                		4 ],
    ChannelAutoDefExit		=> [ 2026,                        	4 ],
    ChannelEvent		=> [ 73,                  		3,		$ResponseValues{ChannelEvent} ],
    ChannelInitiatorControl	=> [ 119,                  		3,	$ResponseValues{ChannelInitiatorControl} ],
    ChinitAdapters		=> [ 101,                   		3 ],
    ChinitDispatchers		=> [ 105,                      		3 ],
    ChinitTraceAutoStart	=> [ 117,                           	3 ],
    ChinitTraceTableSize	=> [ 118,                           	3 ],
    ClusterSenderStatistics	=> [ 130,                           	3,		$ResponseValues{ClusterSenderStatistics} ],
    ClusterWorkLoadData		=> [ 2034,                        	4 ],
    ClusterWorkLoadExit		=> [ 2033,                        	4 ],
    CommandEvent		=> [ 99,                  		3,		$ResponseValues{CommandEvent} ],
    CommandInputQName		=> [ 2003,                       	4 ],
    CommandServerControl	=> [ 120,                      		3,		$ResponseValues{CommandServerControl} ],
    Custom			=> [ 2119,         			3 ],
    DeadLetterQName		=> [ 2006,                     		4 ],
    DefXmitQName		=> [ 2025,                  		4 ],
    Platform			=> [ 32,             			3,		$ResponseValues{Platform} ],
    QMgrDesc			=> [ 2014,             			4 ],
    QMgrIdentifier		=> [ 2032,                   		4 ],
    QMgrName			=> [ 2015,             			4 ],
    RepositoryName		=> [ 2035,                  		4 ],
    RepositoryNamelist		=> [ 2036,                      		4 ],
    AuthorityEvent		=> [ 47,                    		3 ],
    ChannelAutoDef		=> [ 55,                     		3 ],
    ChannelAutoDefEvent		=> [ 56,                           	3 ],
    ChannelMonitoring		=> [ 122,                      		3,		$ResponseValues{QMgrChannelMonitoring} ],
    ChannelStatistics		=> [ 129,                      		3,		$ResponseValues{QMgrChannelStatistics} ],
    ChinitServiceParm		=> [ 2076,                      		4 ],
    ClusterSenderMonitoringDefault => [ 124,                            3 ,	      $ResponseValues{ClusterSenderMonitoringDefault} ],
    ClusterWorkLoadLength	=> [ 58,                            	3 ],
    CLWLMRUChannels		=> [ 97,                      		3 ],
    CLWLUseQ			=> [ 98,              			3,		$ResponseValues{QMgrCLWLUseQ} ],
    CodedCharSetId		=> [ 2,                       		3 ],
    CommandEvent		=> [ 99,                  		3,		       $ResponseValues{CommandEvent} ],
    CommandLevel		=> [ 31,                  		3 ],
    ConfigurationEvent		=> [ 51,                        		3 ],
    CPILevel			=> [ 27,              			3 ],
    DistLists			=> [ 34,               			3 ],
    DNSGroup			=> [ 2071,            			4 ],
    DNSWLM			=> [ 106,           			3 ],
    EncryptionPolicySuiteB	=> [ 247,                    		5,	$ResponseValues{EncryptionPolicySuiteB} ],
    ExpiryInterval		=> [ 39,                    		3 ],
    GroupUR			=> [ 221,            			3,		$ResponseValues{GroupUR} ],
    IGQPutAuthority		=> [ 65,                      		3,		$ResponseValues{IGQPutAuthority} ],
    InhibitEvent		=> [ 48,                  		3 ],
    IntraGroupQueueing		=> [ 64,                        		3 ],
    IGQUserId			=> [ 2041,              			4 ],
    IPAddressVersion		=> [ 93,                       		3,		$ResponseValues{IPAddressVersion} ],
    ListenerTimer		=> [ 107,                  		3 ],
    LocalEvent			=> [ 49,                			3 ],
    LoggerEvent			=> [ 94,                 		3 ],
    LU62ARMSuffix		=> [ 2074,                  		4 ],
    LU62Channels		=> [ 108,                 		3 ],
    LUGroupName			=> [ 2072,                		4 ],
    LUName			=> [ 2073,          			4 ],
    MaxActiveChannels		=> [ 100,                   		3 ],
    MaxChannels			=> [ 109,                		3 ],
    MaxHandles			=> [ 11,                			3 ],
    MaxMsgLength		=> [ 13,                   		3 ],
    MaxPriority			=> [ 14,                 		3 ],
    MaxPropertiesLength		=> [ 192,                         	3,		$ResponseValues{MaxPropertiesLength} ],
    MaxUncommittedMsgs		=> [ 33,                         	3 ],
    MsgMarkBrowseInterval	=> [ 68,                             	3,		$ResponseValues{MsgMarkBrowseInterval} ],
    MQIAccounting		=> [ 133,                  		3 ],
    MQIStatistics		=> [ 127,                  		3 ],
    OutboundPortMax		=> [ 140,                     		3 ],
    OutboundPortMin		=> [ 110,                     		3 ],
    PerformanceEvent		=> [ 53,                      		3 ],
    Parent			=> [ 2102,         			4 ],
    PubSubClus			=> [ 249,                  		3 ],
    PubSubMaxMsgRetryCount	=> [ 206,                             	3 ],
    PubSubMode			=> [ 187,               			3,		$ResponseValues{PubSubMode} ],
    PubSubNPInputMsg		=> [ 203,                 		3,		$ResponseValues{PubSubNPInputMsg} ],
    PubSubNPResponse		=> [ 205,                  		3,		$ResponseValues{PubSubNPResponse} ],
    PubSubSyncPoint		=> [ 207,                  		3,		$ResponseValues{PubSubSyncPoint} ],
    QueueAccounting		=> [ 134,                		3,		$ResponseValues{QMgrAccounting} ],
    QueueMonitoring		=> [ 123,                		3,		$ResponseValues{QMgrMonitoring} ],
    QueueStatistics		=> [ 128,                		3,		$ResponseValues{QMgrQueueStatistics} ],
    QSharingGroupName		=> [ 2040,           			4 ],
    ReceiveTimeout		=> [ 111,                   		3 ],
    ReceiveTimeoutMin		=> [ 113,                       		3 ],
    ReceiveTimeoutType		=> [ 112,                        	3,		$ResponseValues{ReceiveTimeoutType} ],
    RemoteEvent			=> [ 50,                 		3 ],
    ResponseQMgrName		=> [ 3070,                        	4 ],
    ResponseId			=> [ 7004,                		9                   ],
    SecurityCase		=> [ 141,                 		3,		$ResponseValues{SecurityCase} ],
    SharedQQMgrName		=> [ 77,                        		3,		$ResponseValues{SharedQQMgrName} ],
    SSLCRLNamelist		=> [ 2050,                   		4 ],
    SSLCryptoHardware		=> [ 2051,                      		4 ],
    SSLEvent			=> [ 75,              			3 ], # Boolean
    SSLFipsRequired		=> [ 92,                      		3 ], # Boolean
    SSLKeyRepository		=> [ 2049,                     		4 ],
    SSLKeyResetCount		=> [ 76,                    		3 ],
    SSLTasks			=> [ 69,              			3 ],
    StartStopEvent		=> [ 52,                     		3 ],
    StatisticsInterval		=> [ 131,                       		3 ],
    SyncPoint			=> [ 30,              			3 ],
    TCPChannels			=> [ 114,                		3 ],
    TCPKeepAlive		=> [ 115,                  		3 ],
    TCPName			=> [ 2075,           			4 ],
    TCPStackType		=> [ 116,                  		3,		$ResponseValues{TCPStackType} ],
    TraceRouteRecording		=> [ 137,                         	3,		$ResponseValues{TraceRouteRecording} ],
    TreeLifeTime		=> [ 183,                  		3 ],
    TriggerInterval		=> [ 25,                     		3 ],
    Version			=> [ 2120,          			4 ],
    XrCapability			=> [ 243,                 		3 ],
   },

   QueueManagerStatus =>
   {
    ChannelInitiatorStatus	=> [ 1232,                  		3,	$ResponseValues{QMgrServiceStatus}  ],
    CommandServerStatus		=> [ 1233,                      		3,	$ResponseValues{QMgrServiceStatus}  ],
    ConnectionCount		=> [ 1230,                     		3 ],
    CurrentLog			=> [ 3071,                            	4 ],
    InstallationDesc		=> [ 2115,                    		4 ],
    InstallationName		=> [ 2116,                    		4 ],
    InstallationPath		=> [ 2117,                    		4 ],
    LogPath			=> [ 3074,             			4 ],
    MediaRecoveryLog		=> [ 3073,                          	4 ],
    PermitStandby		=> [ 1325,                   		3 ],
    QMgrName			=> [ 2015,             			4 ],
    QMgrStatus			=> [ 1149,                 		3,	$ResponseValues{QMgrStatus}  ],
    RestartRecoveryLog		=> [ 3072,                            	4 ],
    StartDate			=> [ 3175,                     		4 ],
    StartTime			=> [ 3176,                     		4 ],
    Version			=> [ 2120,          			4 ],
   },

   Queue =>
   {
    AlterationDate		=> [ 2027,                  		4 ],
    AlterationTime		=> [ 2028,                  		4 ],
    BackoutRequeueName		=> [ 2019,                     		4 ],
    BackoutThreshold		=> [ 22,                      		3 ],
    BaseQName			=> [ 2002,              			4 ],
    BaseType			=> [ 193,             			3,		$ResponseValues{BaseType} ],
    CFStructure			=> [ 2039,                		4 ],
    ClusterDate			=> [ 2037,               		4 ],
    ClusterName			=> [ 2029,               		4 ],
    ClusterNamelist		=> [ 2030,                   		4 ],
    ClusterQType		=> [ 59,                   		3,		$ResponseValues{ClusterQType} ],
    ClusterTime			=> [ 2038,               		4 ],
    CLWLQueuePriority		=> [ 96,                    		3 ],
    CLWLQueueRank		=> [ 95,                			3 ],
    CLWLUseQ			=> [ 98,              			3,		$ResponseValues{QueueCLWLUseQ} ],
    CreationDate		=> [ 2004,                		4 ],
    CreationTime		=> [ 2005,                		4 ],
    CurrentQDepth		=> [ 3,                     		3 ],
    Custom			=> [ 2119,         			4 ],
    DefBind			=> [ 61,             			3,		$ResponseValues{DefBind} ],
    DefinitionType		=> [ 7,                     		3,		$ResponseValues{DefinitionType} ],
    DefInputOpenOption		=> [ 4,                           	3,		$ResponseValues{DefInputOpenOption} ],
    DefPersistence		=> [ 5,                     		3 ],
    DefPriority			=> [ 6,                  		3 ],
    DefPutResponse		=> [ 184,                         	3,		$ResponseValues{DefPutResponse} ],
    DefReadAhead		=> [ 188,                  		3,		$ResponseValues{DefReadAhead} ],
    DistLists			=> [ 34,               			3 ],
    HardenGetBackout		=> [ 8,                        		3 ],
    HighQDepth			=> [ 36,                 		3 ],
    IndexType			=> [ 57,               			3,		$ResponseValues{IndexType} ],
    InhibitGet			=> [ 9,                 			3 ],
    InhibitPut			=> [ 10,                			3 ],
    InitiationQName		=> [ 2008,                    		4 ],
    MaxMsgLength		=> [ 13,                   		3 ],
    MaxQDepth			=> [ 15,                			3 ],
    MsgDeliverySequence		=> [ 16,                          	3,		$ResponseValues{MsgDeliverySequence} ],
    MsgDeqCount			=> [ 38,                  		3 ],
    MsgEnqCount			=> [ 37,                  		3 ],
    NonPersistentMsgClass	=> [ 78,              			3,		$ResponseValues{NonPersistentMsgClass} ],
    OpenInputCount		=> [ 17,                     		3 ],
    OpenOutputCount		=> [ 18,                      		3 ],
    PageSetId			=> [ 62,               			3 ],
    ProcessName			=> [ 2012,               		4 ],
    PropertyControl		=> [ 190,                    		3,		$ResponseValues{PropertyControl} ],
    QDepthHighEvent		=> [ 43,                       		3 ],
    QDepthHighLimit		=> [ 40,                       		3 ],
    QDepthLowEvent		=> [ 44,                      		3 ],
    QDepthLowLimit		=> [ 41,                      		3 ],
    QDepthMaxEvent		=> [ 42,                      		3 ],
    QDesc			=> [ 2013,         			4 ],
    QMgrIdentifier		=> [ 2032,                   		4 ],
    QMgrName			=> [ 2031,                     		4 ],
    QName			=> [ 2016,         			4 ],
    QNames			=> [ 3011,            			6 ],
    QServiceInterval		=> [ 54,                       		3 ],
    QServiceIntervalEvent	=> [ 46,                             	3,		$ResponseValues{QServiceIntervalEvent} ],
    QSGDisposition		=> [ 63,             			3,		$ResponseValues{QSGDisposition} ],
    QSGDispositions		=> [ 1126,              			5,	$ResponseValues{QSGDisposition} ],
    QType			=> [ 20,           			3,		$ResponseValues{QType} ],
    QTypes			=> [ 1261,            			5,	$ResponseValues{QType} ],
    QueueAccounting		=> [ 134,                		3,		$ResponseValues{QueueAccounting} ],
    QueueMonitoring		=> [ 123,                		3,		$ResponseValues{QueueMonitoring} ],
    QueueStatistics		=> [ 128,                		3,		$ResponseValues{QueueStatistics} ],
    RemoteQMgrName		=> [ 2017,                    		4 ],
    RemoteQName			=> [ 2018,                		4 ],
    ResponseId			=> [ 7004,                		9                   ],
    ResponseQMgrName		=> [ 3070,                        	4 ],
    RetentionInterval		=> [ 21,                       		3 ],
    Scope			=> [ 45,          			3,		$ResponseValues{Scope} ],
    Shareability		=> [ 23,                 		3 ],
    StorageClass		=> [ 2022,                		4 ],
    TimeSinceReset		=> [ 35,                     		3 ],
    TPipeNames			=> [ 2085,             			4 ],
    TriggerControl		=> [ 24,                    		3 ],
    TriggerData			=> [ 2023,               		4 ],
    TriggerDepth		=> [ 29,                  		3 ],
    TriggerMsgPriority		=> [ 26,                         	3 ],
    TriggerType			=> [ 28,                 		3,		$ResponseValues{TriggerType} ],
    Usage			=> [ 12,          			3,		$ResponseValues{Usage} ],
    XmitQName			=> [ 2024,              			4 ],
   },

   QSharingGroup =>
   {
    CommandLevel		=> [ 31,                  		3 ],
    DB2ConnectStatus		=> [ 1150,                    		3,		$ResponseValues{QSGStatus} ],
    DB2Name			=> [ 3109,             			4 ],
    QMgrCPF			=> [ 3076,              			4 ],
    QMgrName			=> [ 2015,             			4 ],
    QMgrNumber			=> [ 1148,                 		3 ],
    QMgrStatus			=> [ 1149,                 		3,		$ResponseValues{QSGStatus} ],
    QSGName			=> [ 2040,           			4 ],
    CFMsgIdentifier		=> [ 7014,            			4 ],
    CommandInformation		=> [ 1120,                 		3,		$ResponseValues{CommandInformation} ],
   },

   Process =>
   {
    ApplType			=> [ 1,               			3,		$ResponseValues{ApplType} ],

    ProcessNames		=> [ 3012,                  		6 ],
    AlterationDate		=> [ 2027,                  		4 ],
    AlterationTime		=> [ 2028,                  		4 ],
    CreationDate		=> [ 2004,                		4 ],
    CreationTime		=> [ 2005,                		4 ],
    ApplId			=> [ 2001,          			4 ],
    EnvData			=> [ 2007,           			4 ],
    ProcessDesc			=> [ 2011,               		4 ],
    ProcessName			=> [ 2012,               		4 ],
    QSGDisposition		=> [ 63,             			3,		$ResponseValues{QSGDisposition} ],
    QSGDispositions		=> [ 1126,              			5,	$ResponseValues{QSGDisposition} ],
    ResponseId			=> [ 7004,                		9                   ],
    ResponseQMgrName		=> [ 3070,                        	4 ],
    UserData			=> [ 2021,            			4 ],
   },

   Channel =>
   {
    AlterationDate		=> [ 2027,                  		4 ],
    AlterationTime		=> [ 2028,                  		4 ],
    BatchDataLimit		=> [ 1624,                     		3 ],
    BatchHeartBeat		=> [ 1567,             			3 ],
    BatchInterval		=> [ 1564,                   		3 ],
    BatchSize			=> [ 1502,               		3 ],
    ChannelDesc			=> [ 3502,         			4 ],
    ChannelDisposition		=> [ 1580,                 		3,		$ResponseValues{ChannelDisposition} ],
    ChannelMonitoring		=> [ 122,                      		3,		$ResponseValues{ChannelMonitoring} ],
    ChannelStatistics		=> [ 129,                      		3,		$ResponseValues{ChannelStatistics} ],
    ChannelName			=> [ 3501,                 		4 ],
    ChannelNames		=> [ 3512,                  		6 ],
    ChannelType			=> [ 1511,                 		3,		$ResponseValues{ChannelType} ],
    ChannelTypes		=> [ 1582,                  		5,		$ResponseValues{ChannelType} ],
    ClientChannelWeight		=> [ 1620,                          	3 ],
    ClusterName			=> [ 2029,               		4 ],
    ClusterNamelist		=> [ 2030,                   		4 ],
    CLWLChannelPriority		=> [ 1578,                          	3 ],
    CLWLChannelRank		=> [ 1577,                      		3 ],
    CLWLChannelWeight		=> [ 1579,                        	3 ],
    ConnectionAffinity		=> [ 1621,                        	3,		$ResponseValues{ConnectionAffinity} ],
    ConnectionName		=> [ 3506,                    		4 ],
    CreationDate		=> [ 2004,                		4 ],
    CreationTime		=> [ 2005,                		4 ],
    DataConversion		=> [ 1515,                    		3 ],
    DefReconnect		=> [ 1640,                  		3,		$ResponseValues{DefReconnect} ],
    DefaultChannelDisposition	=> [ 1614,                     		3,		$ResponseValues{ChannelDisposition} ],
    DiscInterval		=> [ 1503,                  		3 ],
    HeaderCompression		=> [ 1575,                    		5,	$ResponseValues{HeaderCompression} ],
    HeartbeatInterval		=> [ 1563,                		3 ],
    KeepAliveInterval		=> [ 1566,                        	3,		$ResponseValues{KeepAliveInterval} ],
    LocalAddress		=> [ 3520,                  		4 ],
    LongRetryCount		=> [ 1507,               		3 ],
    LongRetryInterval		=> [ 1506,               		3 ],
    MCAName			=> [ 3507,             			4 ],
    MCAType			=> [ 1517,             			3,		$ResponseValues{MCAType} ],
    MCAUserIdentifier		=> [ 3527,                		4 ],
    MaxInstances		=> [ 1618,                  		3 ],
    MaxInstancesPerClient	=> [ 1619,                         	3 ],
    MaxMsgLength		=> [ 1510,                   		3 ],
    ModeName			=> [ 3503,              			4 ],
    MessageCompression		=> [ 1576,                    		5,		$ResponseValues{MessageCompression} ],
    MsgExit			=> [ 3509,                  		4 ],
    MsgRetryCount		=> [ 1544,             			3 ],
    MsgRetryExit		=> [ 3534,                 		4 ],
    MsgRetryInterval		=> [ 1545,                		3 ],
    MsgRetryUserData		=> [ 3535,                      		4 ],
    MsgUserData			=> [ 3514,                       	4 ],
    NetworkPriority		=> [ 1565,                     		3 ],
    NonPersistentMsgSpeed	=> [ 1562,              			3,		$ResponseValues{NonPersistentMsgSpeed} ],
    Password			=> [ 3518,             			4 ],
    PropertyControl		=> [ 190,                    		3,		$ResponseValues{PropertyControl} ],
    PutAuthority		=> [ 1508,                  		3,		$ResponseValues{PutAuthority} ],
    QMgrName			=> [ 2015,             			4 ],
    QSGDisposition		=> [ 63,             			3,		$ResponseValues{QSGDisposition} ],
    QSGDispositions		=> [ 1126,              			5,		$ResponseValues{QSGDisposition} ],
    ReceiveExit			=> [ 3511,                  		4 ],
    ReceiveUserData		=> [ 3516,                       	4 ],
    ResetRequested		=> [ 1623,                    		3 ],
    ResponseId			=> [ 7004,                		9                   ],
    ResponseQMgrName		=> [ 3070,                        	4 ],
    SecurityExit		=> [ 3508,                  		4 ],
    SecurityUserData		=> [ 3513,                       	4 ],
    SendExit			=> [ 3510,                   		4 ],
    SendUserData		=> [ 3515,                        	4 ],
    SeqNumberWrap		=> [ 1509,                         	3 ],
    SharingConversations	=> [ 1615,                          	3 ],
    ShortRetryCount		=> [ 1505,                		3 ],
    ShortRetryInterval		=> [ 1504,                		3 ],
    SSLCipherSpec		=> [ 3544,                    		4 ],
    SSLClientAuth		=> [ 1568,                    		3,		$ResponseValues{SSLClientAuth} ],
    SSLPeerName			=> [ 3545,                  		4 ],
    TpName			=> [ 3504,            			4 ],
    TransportType		=> [ 1501,                       	3,		$ResponseValues{TransportType} ],
    UserIdentifier		=> [ 3517,            			4 ],
    XmitQName			=> [ 3505,                		4 ],
    UseDLQ			=> [ 234,                     		3,		$ResponseValues{UseDLQ} ],
   },

   #
   # MQ 7.1 introducted ChannelAuthRecords
   #

   ChlAuthRec =>
   {
    Action                      => [ 1086,                               3,            $ResponseVaues{ChlAuthAction} ],
    Address			=> [ 3506,                    		4 ],
    Addrlist			=> [ 3566,                         	6 ],
    AlterationDate		=> [ 2027,                  		4 ],
    AlterationTime		=> [ 2028,                  		4 ],
    ChlAuth			=> [ 3501,                 		4 ],
    ChlAuthDesc                 => [ 2118,                               4, ],
    ClientUserId		=> [ 3567,                   		4 ],
    Custom                      => [ 2119,                               4 ],
    MCAUserIdentifier		=> [ 3527,                		4 ],
    RemoteQMgrName		=> [ 2017,                    		4 ],
    SSLPeerName			=> [ 3545,                  		4 ],
    ChlAuthType			=> [ 1352,                 		3,		$ResponseValues{ChlAuthType} ],
    MCAUserIdList		=> [ 3568,                     		6 ],
    UserSource			=> [ 1638,                		3,		$ResponseValues{UserSource} ],
    Warning			=> [ 1639,            			3 ],
   },
    #ChlAuthAttrs                => [ 1355,                               5,            $RequestValues{ChlAuthAttrs} ],
    #CommandScope                => [ 3080,                               4 ],
    #Match                       => [ 1637,                               3,         $RequestValues{ChlAuthMatch} ],


   #
   # ChannelInitiator is used for InquireChannelInitiator; Z/OS only
   #
   ChannelInitiator =>
   {
    ActiveChannels		=> [ 1593,               		3 ],
    ActiveChannelsMax		=> [ 1594,                   		3 ],
    ActiveChannelsPaused	=> [ 1595,                      		3 ],
    ActiveChannelsRetrying	=> [ 1598,                     		3 ],
    ActiveChannelsStarted	=> [ 1596,                       	3 ],
    ActiveChannelsStopped	=> [ 1597,                       	3 ],
    AdpatersMax			=> [ 1584,              			3 ],
    AdpatersStarted		=> [ 1583,                  		3 ],
    ChannelInitiatorStatus	=> [ 1232,                  		3,		$ResponseValues{ServiceStatus} ],
    CurrentChannels		=> [ 1589,                		3 ],
    CurrentChannelsLU62		=> [ 1592,                     		3 ],
    CurrentChannelsMax		=> [ 1590,                    		3 ],
    CurrentChannelsTCP		=> [ 1591,                    		3 ],
    DispatchersMax		=> [ 1586,              			3 ],
    DispatchersStarted		=> [ 1585,                  		3 ],
    InboundDisposition		=> [ 1581,                 		3 ],
    IPAddress			=> [ 3552,               		4 ],
    ListenerStatus		=> [ 1599,                    		3,		$ResponseValues{ListenerStatus} ],
    LUName			=> [ 2073,          			4 ],
    Port			=> [ 1574,                		3 ],
    SSLTasksMax			=> [ 1588,                 		3 ],
    SSLTasksStarted		=> [ 1587,                     		3 ],
    TCPName			=> [ 3553,             			4 ],
    TransportType		=> [ 1501,                       	3,		$ResponseValues{TransportType} ],
   },

   #
   # ChannelStatus is used for InquireChannelStatus
   #
   ChannelStatus =>
   {
    Batches			=> [ 1537,            			3 ],
    BatchSize			=> [ 1502,               		3 ],
    BatchSizeIndicator		=> [ 1607,                         	5 ],
    BuffersReceived		=> [ 1539,                 		3 ],
    BuffersSent			=> [ 1538,                 		3 ],
    BytesReceived		=> [ 1536,               		3 ],
    BytesSent			=> [ 1535,               		3 ],
    ChannelDisposition		=> [ 1580,                 		3,		$ResponseValues{ChannelDisposition} ],
    ChannelInstanceType		=> [ 1523,                          	3,		$ResponseValues{ChannelInstanceType} ],
    ChannelMonitoring		=> [ 122,                      		3,		$ResponseValues{MonitoringDft} ],
    ChannelName			=> [ 3501,                 		4 ],
    ChannelStartDate		=> [ 3529,                       	4 ],
    ChannelStartTime		=> [ 3528,                       	4 ],
    ChannelStatus		=> [ 1527,                   		3,		$ResponseValues{ChannelStatus} ],
    ChannelType			=> [ 1511,                 		3,		$ResponseValues{ChannelType} ],
    ClientIdentifier		=> [ 3564,              			4 ],
    CompressionRate		=> [ 1611,                     		5 ],
    CompressionTime		=> [ 1612,                     		5 ],
    ConnectionName		=> [ 3506,                    		4 ],
    CurrentLUWID		=> [ 3532,                  		4 ],
    CurrentMsgs			=> [ 1531,                 		3 ],
    CurrentSequenceNumber	=> [ 1532,                       	3 ],
    CurrentSharingConversations	=> [ 1617,                          	3 ],
    ExitTime			=> [ 1606,                        	5 ],
    HeaderCompression		=> [ 1575,                    		5,		$ResponseValues{HeaderCompression} ],
    HeartbeatInterval		=> [ 1563,                		3 ],
    InDoubtStatus		=> [ 1528,                   		3 ],
    KeepAliveInterval		=> [ 1566,                        	3,		$ResponseValues{KeepAliveInterval} ],
    LastLUWID			=> [ 3531,               		4 ],
    LastMsgDate			=> [ 3525,                  		4 ],
    LastMsgTime			=> [ 3524,                  		4 ],
    LastSequenceNumber		=> [ 1529,                    		3 ],
    LocalAddress		=> [ 3520,                  		4 ],
    LongRetriesLeft		=> [ 1540,                      		3 ],
    MaxMsgLength		=> [ 1510,                   		3 ],
    MaxSharingConversations	=> [ 1616,                      		3 ],
    MCAJobName			=> [ 3530,                 		4 ],
    MCAStatus			=> [ 1542,               		3,		$ResponseValues{MCAStatus} ],
    MCAUserIdentifier		=> [ 3527,                		4 ],
    MessageCompression		=> [ 1576,                    		3,		$ResponseValues{MessageCompression} ],
    Msgs			=> [ 1534,         			3 ],
    MsgsAvailable		=> [ 1608,                         	3 ],
    NetTime			=> [ 1605,                           	3 ],
    NonPersistentMsgSpeed	=> [ 1562,              			3,		$ResponseValues{NonPersistentMsgSpeed} ],
    QMgrName			=> [ 2015,             			4 ],
    RemoteApplTag		=> [ 3548,                    		4 ],
    RemoteProduct		=> [ 3561,                   		4 ],
    RemoteQMgrName		=> [ 2017,                    		4 ],
    RemoteVersion		=> [ 3560,                   		4 ],
    ResponseId			=> [ 7004,                		9                   ],
    ResponseQMgrName		=> [ 3070,                        	4 ],
    SSLCertRemoteIssuerName	=> [ 3550,                         	4 ],
    SSLCertUserId		=> [ 3549,                     		4 ],
    SSLKeyResetDate		=> [ 3558,                       	4 ],
    SSLKeyResets		=> [ 1610,                   		3 ],
    SSLKeyResetTime		=> [ 3559,                       	4 ],
    SSLShortPeerName		=> [ 3547,                        	4 ],
    ShortRetriesLeft		=> [ 1541,                       	3 ],
    StopRequested		=> [ 1543,                   		3 ],
    SubState			=> [ 1609,                     		3,		$ResponseValues{ChannelSubState} ],
    XmitQName			=> [ 3505,                		4 ],
    XQTime			=> [ 1604,                         	5 ],
   },

   Escape =>
   {
    EscapeText			=> [ 3014,                		4 ],
    EscapeType			=> [ 1017,                		3,		$ResponseValues{EscapeType} ],
   },

   #
   # New entries for MQSeries 5.1
   #
   Cluster =>
   {
    BatchHeartBeat		=> [ 1567,             			3 ],
    ClusterQMgrName		=> [ 2031,                     		4 ],
    ChannelStatus		=> [ 1527,                   		3,		$ResponseValues{ChannelStatus} ],
    ChannelName			=> [ 3501,                 		4 ],
    ConnectionName		=> [ 3506,                    		4 ],
    ChannelDesc			=> [ 3502,         			4 ],
    KeepAliveInterval		=> [ 1566,                        	3,		$ResponseValues{KeepAliveInterval} ],
    LocalAddress		=> [ 3520,                  		4 ],
    MCAName			=> [ 3507,             			4 ],
    MCAType			=> [ 1517,             			3,		$ResponseValues{MCAType} ],
    MCAUserIdentifier		=> [ 3527,                		4 ],
    ModeName			=> [ 3503,              			4 ],
    MsgRetryExit		=> [ 3534,                 		4 ],
    MsgRetryUserData		=> [ 3535,                      		4 ],
    MsgExit			=> [ 3509,                  		4 ],
    MsgUserData			=> [ 3514,                       	4 ],
    NonPersistentMsgSpeed	=> [ 1562,              			3,		$ResponseValues{NonPersistentMsgSpeed} ],
    Password			=> [ 3518,             			4 ],
    PutAuthority		=> [ 1508,                  		3,		$ResponseValues{PutAuthority} ],
    QMgrDefinitionType		=> [ 1084,                          	3,		$ResponseValues{QMgrDefinitionType} ],
    QMgrType			=> [ 1085,               		3,		$ResponseValues{QMgrType} ],
    ReceiveExit			=> [ 3511,                  		4 ],
    ReceiveUserData		=> [ 3516,                       	4 ],
    ResponseId			=> [ 7004,                		9                   ],
    ResponseQMgrName		=> [ 3070,                        	4 ],
    SecurityExit		=> [ 3508,                  		4 ],
    SecurityUserData		=> [ 3513,                       	4 ],
    SendExit			=> [ 3510,                   		4 ],
    SendUserData		=> [ 3515,                        	4 ],
    TpName			=> [ 3504,            			4 ],
    TransportType		=> [ 1501,                       	3,		$ResponseValues{TransportType} ],
    UserIdentifier		=> [ 3517,            			4 ],
    XmitQName			=> [ 3505,                		4 ],
    AlterationDate		=> [ 2027,                  		4 ],
    AlterationTime		=> [ 2028,                  		4 ],
    CreationDate		=> [ 2004,                		4 ],
    CreationTime		=> [ 2005,                		4 ],
    ClusterDate			=> [ 2037,               		4 ],
    ClusterName			=> [ 2029,               		4 ],
    ClusterTime			=> [ 2038,               		4 ],
    QMgrIdentifier		=> [ 2032,                   		4 ],
    QMgrName			=> [ 2015,             			4 ],
    ClusterInfo			=> [ 1083,                 		3 ],
    Suspend			=> [ 1087,            			3 ],
    BatchInterval		=> [ 1564,                   		3 ],
    BatchSize			=> [ 1502,               		3 ],
    DataConversion		=> [ 1515,                    		3 ],
    DiscInterval		=> [ 1503,                  		3 ],
    HeartbeatInterval		=> [ 1563,                		3 ],
    LongRetryCount		=> [ 1507,               		3 ],
    LongRetryInterval		=> [ 1506,               		3 ],
    MaxMsgLength		=> [ 1510,                   		3 ],
    MsgRetryCount		=> [ 1544,             			3 ],
    MsgRetryInterval		=> [ 1545,                		3 ],
    NetworkPriority		=> [ 1565,                     		3 ],
    SeqNumberWrap		=> [ 1509,                         	3 ],
    ShortRetryCount		=> [ 1505,                		3 ],
    ShortRetryInterval		=> [ 1504,                		3 ],
    SSLCipherSpec		=> [ 3544,                    		4 ],
    SSLClientAuth		=> [ 1568,                    		3,			$ResponseValues{SSLClientAuth} ],
    SSLPeerName			=> [ 3545,                  		4 ],
   },

   Namelist =>
   {
    AlterationDate		=> [ 2027,                  		4 ],
    AlterationTime		=> [ 2028,                  		4 ],
    CreationDate		=> [ 2004,                		4 ],
    CreationTime		=> [ 2005,                		4 ],
    NameCount			=> [ 19,               			3 ],
    NamelistDesc		=> [ 2009,                		4 ],
    NamelistName		=> [ 2010,                		4 ],
    NamelistNames		=> [ 3013,                   		6 ],
    NamelistType		=> [ 72,                  		3,		 $ResponseValues{NamelistType}],
    Names			=> [ 2020,        			4 ],
    ResponseId			=> [ 7004,                		9                   ],
    ResponseQMgrName		=> [ 3070,                        	4 ],
    QSGDisposition		=> [ 63,             			3,		$ResponseValues{QSGDisposition} ],
    QSGDispositions		=> [ 1126,              			5,	$ResponseValues{QSGDisposition} ],
   },

   #
   # AuthInfo is new with WebSphere MQ 5.3
   #
   AuthInfo =>
   {
    AlterationDate		=> [ 2027,                  		4 ],
    AlterationTime		=> [ 2028,                  		4 ],
    AuthInfoConnName		=> [ 2053,                      		4 ],
    AuthInfoDesc		=> [ 2046,                 		4 ],
    AuthInfoName		=> [ 2045,                 		4 ],
    AuthInfoNames		=> [ 3048,                    		6 ],
    AuthInfoType		=> [ 66,                   		3,                $ResponseValues{AuthInfoType} ],
    LDAPPassword		=> [ 2048,                		4 ],
    LDAPUserName		=> [ 2047,                 		4 ],
    OCSPResponderURL		=> [ 2109,                     		4 ],
    ResponseId			=> [ 7004,                		9                   ],
    ResponseQMgrName		=> [ 3070,                        	4 ],
    QSGDisposition		=> [ 63,             			3,		$ResponseValues{QSGDisposition} ],
    QSGDispositions		=> [ 1126,              			5,	        $ResponseValues{QSGDisposition} ],
   },

   #
   # QueueStatus is new with WebSphere MQ 5.3
   #
   QueueStatus =>
   {
    ApplDesc			=> [ 3174,              			4 ],
    ApplTag			=> [ 3058,             			4 ],
    ApplType			=> [ 1,               			3,			$ResponseValues{ApplType} ],
    ASId			=> [ 3081,         			4, ],
    AsynchronousState          => [ 1308,                		3,                $ResponseValues{AsynchronousState} ],
    ChannelName			=> [ 3501,                 		4 ],
    Conname			=> [ 3506,                    		4 ],
    CurrentQDepth		=> [ 3,                     		3 ],
    ExternalUOWId		=> [ 7005,                    		9                   ],
    HandleState			=> [ 1028,                 		3,		$ResponseValues{HandleState} ],
    LastGetDate			=> [ 3130,                  		4 ],
    LastGetTime			=> [ 3131,                  		4 ],
    LastPutDate			=> [ 3128,                  		4 ],
    LastPutTime			=> [ 3129,                  		4 ],
    MediaRecoveryLog		=> [ 3073,                          	4 ],
    OldestMsgAge		=> [ 1227,                   		3 ],
    OnQTime			=> [ 1226,                     		5 ],
    OpenBrowse			=> [ 1102,                		3 ],
    OpenInputCount		=> [ 17,                     		3 ],
    OpenInputType		=> [ 1098,                    		3,		$ResponseValues{QStatusInputType} ],
    OpenInquire			=> [ 1101,                 		3 ],
    OpenOptions			=> [ 1022,                 		3 ],
    OpenOutputCount		=> [ 18,                      		3 ],
    OpenOutput			=> [ 1099,                		3 ],
    OpenSet			=> [ 1100,             			3 ],
    OpenType			=> [ 1023,              			3,		$ResponseValues{OpenType} ],
    PSBName			=> [ 3082,             			4 ],
    PSTId			=> [ 3083,           			4 ],
    ProcessId			=> [ 1024,               		3 ],
    QMgrUOWId			=> [ 7009,                 		9                   ],
    QName			=> [ 2016,         			4 ],
    QSGDisposition		=> [ 63,             			3,		$ResponseValues{QSGDisposition} ],
    QueueMonitoring		=> [ 123,                		3,		$ResponseValues{QMgrMonitoring} ],
    StatusType			=> [ 1103,                  		4,		$ResponseValues{QStatusType} ],
    TaskNumber			=> [ 3084,                		4 ],
    ThreadId			=> [ 1025,              			3 ],
    TransactionId		=> [ 3085,                   		4 ],
    UOWIdentifier		=> [ 7005,                    		9                   ],
    UOWType			=> [ 1132,             			3,		$ResponseValues{UOWType} ],
    UncommittedMsgs		=> [ 1027,                     		3 ],
    UserIdentifier		=> [ 3025,                    		4 ],
   },

   #
   # CFStruc is for MQ on z/OS
   #
   # NOTE: we keep the fields as 'CFStructXXX' as that is the name we picked
   #	   for MQSC in the MQ 5.2 days.
   #
   CFStruc =>
   {
    Access			=> [ 1332,                    		3,		$ResponseValues{CFStrucAccess} ],
    AlterationDate		=> [ 2027,                  		4 ],
    AlterationTime		=> [ 2028,                  		4 ],
    BackupDate			=> [ 3098,                		4 ],
    BackupEndRBA		=> [ 3102,                        	4 ],
    BackupSize			=> [ 1144,                         	3 ],
    BackupStartRBA		=> [ 3101,                          	4 ],
    BackupTime			=> [ 3099,                		4 ],
    CFConlos			=> [ 246,               			3,         $ResponseValues{CFConlos} ],
    CFStatusType		=> [ 1135,                   		3,		$ResponseValues{CFStatusType} ],
    CFStrucDesc			=> [ 2052,                		4 ],
    CFStrucName			=> [ 2039,                		4 ],
    CFStrucNames		=> [ 3095,                   		6 ],
    CFStrucStatus		=> [ 1130,                    		3,		$ResponseValues{CFStrucStatus} ],
    CFStrucType			=> [ 1139,                  		3,		$ResponseValues{CFStrucType} ],
    CFLevel			=> [ 70,             			3 ],
    DSBlock			=> [ 1328,                       		3,         $ResponseValues{DSBlock} ],
    DSBufs			=> [ 228,                   		3 ],
    DSExpand			=> [ 1329,                   		3,		$ResponseValues{DSExpand} ],
    DSGroup			=> [ 3182,                         	4 ],

    EntriesMax			=> [ 1142,                         	3 ],
    EntriesUsed			=> [ 1143,                          	3 ],
    FailDate			=> [ 3096,              			4 ],
    FailTime			=> [ 3097,              			4 ],
    LogQMgrNames		=> [ 3103,                        	6 ],
    QMgrName			=> [ 2015,             			4 ],
    Offload			=> [ 224,              			3,		$ResponseValues{Offload} ],
    OffLdUse			=> [ 229,               		3,		$ResponseValues{OffLdUse} ],
    OFFLD1SZ			=> [ 3179,                     		4 ],
    OFFLD2SZ			=> [ 3180,                     		4 ],
    OFFLD3SZ			=> [ 3181,                     		4 ],
    OFFLD1TH			=> [ 225,                         	3 ],
    OFFLD2TH			=> [ 226,                         	3 ],
    OFFLD3TH			=> [ 227,                         	3 ],
    Recauto			=> [ 244,              			3 ],
    Recovery			=> [ 71,               			3 ],

    SizeMax			=> [ 1140,                      		3 ],
    SizeUsed			=> [ 1141,                       	3 ],
    SysName			=> [ 3100,                		4 ],
    Recovery			=> [ 71,               			3 ],
    RcvDate			=> [ 3184,                  		4 ],
    RcvTime			=> [ 3185,                  		4 ],
    ResponseId			=> [ 7004,                		9                   ],
    ResponseQMgrName		=> [ 3070,                        	4 ],
   },

   #
   # CFStruct is for MQ on z/OS
   #
   # NOTE: CFStruct is for backwards compatibility with pre-1.24 MQSC
   #	   New code should use CFStruc (no final 't')
   #
   CFStruct =>
   {
    AlterationDate		=> [ 2027,                  		4 ],
    AlterationTime		=> [ 2028,                  		4 ],
    CFStructDesc		=> [ 2052,                		4 ],
    CFStructName		=> [ 2039,                		4 ],
    CFStructNames		=> [ 3095,                   		6 ],
    CFStructLevel		=> [ 70,             			3 ],
    Recovery			=> [ 71,               			3 ],
    ResponseId			=> [ 7004,                		9                   ],
    ResponseQMgrName		=> [ 3070,                        	4 ],
    CFConlos			=> [ 246,               			3,         $ResponseValues{CFConlos} ],
    DSBlock			=> [ 1328,                       		3,         $ResponseValues{DSBlock} ],
    DSBufs			=> [ 228,                   		3 ],
    DSExpand			=> [ 1329,                   		3,		$ResponseValues{DSExpand} ],
    DSGroup			=> [ 3182,                         	4 ],
    Offload			=> [ 224,              			3,		$ResponseValues{Offload} ],
    OffLdUse			=> [ 229,               		3,		$ResponseValues{OffLdUse} ],
    OFFLD1SZ			=> [ 3179,                     		4 ],
    OFFLD2SZ			=> [ 3180,                     		4 ],
    OFFLD3SZ			=> [ 3181,                     		4 ],
    OFFLD1TH			=> [ 225,                         	3 ],
    OFFLD2TH			=> [ 226,                         	3 ],
    OFFLD3TH			=> [ 227,                         	3 ],
    Recauto			=> [ 244,              			3 ],
   },

   #
   # StorageClass is for MQ on z/OS
   #
   # NOTE: we keep the key fields as 'StorageClassName' as that is the
   # name we picked for MQSC in the MQ 5.2 days.
   #
   StorageClass =>
   {
    AlterationDate		=> [ 2027,                  		4 ],
    AlterationTime		=> [ 2028,                  		4 ],
    PageSetId			=> [ 62,               			3 ],
    PassTicketApplication	=> [ 2086,                   		4 ],
    QSGDisposition		=> [ 63,             			3,		$ResponseValues{QSGDisposition} ],
    QSGDispositions		=> [ 1126,              			5,	$ResponseValues{QSGDisposition} ],
    ResponseId			=> [ 7004,                		9                   ],
    ResponseQMgrName		=> [ 3070,                        	4 ],
    StorageClassDesc		=> [ 2042,                     		4 ],
    StorageClassName		=> [ 2022,                		4 ],
    StorageClassNames		=> [ 3106,                        	6 ],
    XCFGroupName		=> [ 2043,                 		4 ],
    XCFMemberName		=> [ 2044,                  		4 ],
   },

   #
   # InquireSystem is for MQ on z/OS
   #
   InquireSystem =>
   {
    ParameterType		=> [ 1175,              			3,		$ResponseValues{ParameterType} ],
    CheckpointCount		=> [ 1191,                        	3 ],
    ClusterCacheType		=> [ 1266,                       	3,		$ResponseValues{ClusterCacheType} ],
    CodedCharSetId		=> [ 2,                       		3 ],
    CommandUserId		=> [ 3110,                     		4 ],
    DB2BlobTasks		=> [ 1267,                        	3 ],
    DB2Name			=> [ 3109,             			4 ],
    DB2Tasks			=> [ 1194,                   		3 ],
    DSGName			=> [ 3108,             			4 ],
    ExitInterval		=> [ 1189,                       	3 ],
    ExitTasks			=> [ 1190,                    		3 ],
    MaxConnects			=> [ 1186,                   		3 ],
    MaxConnectsBackground	=> [ 1188,                        	3 ],
    MaxConnectsForeground	=> [ 1187,                        	3 ],
    MULCCapture			=> [ 1324,                 		3,		$ResponseValues{MULCCapture} ],
    OpMode			=> [ 1326,                   		5 ],
    OTMADruExit			=> [ 3113,                       	4 ],
    OTMAGroup			=> [ 3111,                    		4 ],
    OTMAInterval		=> [ 1192,                       	3 ],
    OTMAMember			=> [ 3112,                     		4 ],
    OTMSTpipePrefix		=> [ 3114,                        	4 ],
    QIndexDefer			=> [ 1193,                       	3 ],
    QSGName			=> [ 2040,           			4 ],
    RESLEVELAudit		=> [ 1195,                        	3 ],
    RoutingCode			=> [ 1196,                      		5 ],
    Service			=> [ 3123,                 		4 ],
    SMFAccounting		=> [ 1197,                        	3 ],
    SMFStatistics		=> [ 1198,                   		3 ],
    SMFInterval			=> [ 1199,                      		3 ],
    TraceClass			=> [ 1200,                     		5 ],
    TraceSize			=> [ 1201,                    		3 ],
    WLMInterval			=> [ 1202,                      		3 ],
    WLMIntervalUnits		=> [ 1268,                       	3,		$ResponseValues{WLMIntervalUnits} ],
   },

   #
   # InquireUsage is for MQ on z/OS
   #
   InquireUsage =>
   {
    BufferPoolId		=> [ 1158,                   		3 ],
    DataSetName			=> [ 3059,                  		4 ],
    DataSetType			=> [ 1167,                        	3,		$ResponseValues{UsageDataSetType} ],
    ExpandCount			=> [ 1164,                       	3 ],
    ExpandType			=> [ 1265,                      		3,		$ResponseValues{UsageExpandType} ],
    LogRBA			=> [ 3078,                  		4 ],
    LogLRSN			=> [ 3079,                   		4 ],
    NonPersistentDataPages	=> [ 1162,                           	3 ],
    PageSetId			=> [ 62,               			3 ],
    PageSetStatus		=> [ 1165,                   		3,		$ResponseValues{UsagePageSetStatus} ],
    PersistentDataPages		=> [ 1161,                        	3 ],
    ResponseId			=> [ 7004,                		9                   ],
    ResponseQMgrName		=> [ 3070,                        	4 ],
    TotalBuffers		=> [ 1166,                        	3 ],
    TotalPages			=> [ 1159,                      		3 ],
    UnusedPages			=> [ 1160,                       	3 ],
    UsageType			=> [ 1157,               		3,		$ResponseValues{UsageType} ],
   },

   Connection =>
   {
    ApplDesc		       => [ 3174,              			4 ],
    ApplTag		       => [ 3058,             			4 ],
    ApplType		       => [ 1,               			3,	        $ResponseValues{ConnApplType} ],
    ASID		       => [ 3081,         			4 ],
    AsynchronousState          => [ 1308,                		3,                $ResponseValues{AsynchronousState} ],
    ChannelName		       => [ 3501,                 		4 ],
    ConnectionId	       => [ 7006,                  		9                   ],
    ConnectionName	       => [ 3506,                    		4 ],
    ConnectionOptions	       => [ 1108,                    		5 ],
    ConnInfoType	       => [ 1110,                   		3 ,	        $ResponseValues{ConnInfoType} ],
    Destination 	       => [ 3154,                		4 ],
    DestinationQMgr	       => [ 3153,                      		4 ],
    GenericConnectionId        => [ 7007,                                9                   ],
    HandleState		       => [ 1028,                 		3,	        $ResponseValues{HandleState} ],
    ObjectName		       => [ 3046,                		4 ],
    ObjectType		       => [ 1016,                		3,	        $ResponseValues{HandleObjectType} ],
    OpenOptions		       => [ 1022,                 		3 ],
    OriginName		       => [ 3088,                		4 ],
    OriginUOWId		       => [ 7008,                  		9                   ],
    ProcessId		       => [ 1024,               			3 ],
    PSBName		       => [ 3082,             			4 ],
    PSTId		       => [ 3083,           			4 ],
    QMgrUOWId		       => [ 7009,                 		9                   ],
    QSGDisposition	       => [ 63,             			3,		$ResponseValues{HandleQSGDisposition} ] ,
    ReadAhead		       => [ 189,              		        3,		$ResponseValues{DefReadAhead} ],
    ResponseId			=> [ 7004,                		9                   ],
    ResponseQMgrName		=> [ 3070,                        	4 ],
    StartUOWLogExtent	       => [ 3064,                        	4 ],
    SubId		       => [ 7016,           			9                   ],
    SubName		       => [ 3152,             			4 ],
    TaskNumber		       => [ 3084,                		4 ],
    ThreadId		       => [ 1025,              			3 ],
    TopicString		       => [ 2094,               			4 ],
    TransactionId	       => [ 3085,                   		4 ],
    UOWIdentifier	       => [ 7005,                    		9                   ],
    UOWLogStartDate	       => [ 3062,                       		4 ],
    UOWLogStartTime	       => [ 3063,                       		4 ],
    UOWStartDate	       => [ 3060,                   		4 ],
    UOWStartTime	       => [ 3061,                   		4 ],
    UOWState		       => [ 1128,              			3,		     $ResponseValues{UOWState} ],
    UOWType		       => [ 1132,             			3,		     $ResponseValues{UOWType} ],
    URDisposition	       => [ 222,           			3,		$ResponseValues{URDisposition} ],
    UserId		       => [ 3025,                    		4],
   },

   #
   # InquireSecurity
   #
   InquireSecurity =>
   {
    SecurityInterval		=> [ 1153,                      		3 ],
    SecuritySwitch		=> [ 1154,                    		3,		$ResponseValues{SecuritySwitch} ],
    SecuritySwitchProfile	=> [ 3090,                     		4 ],
    SecuritySwitchSetting	=> [ 1155,                     		3,		$ResponseValues{SecuritySwitchSetting} ],
    SecurityTimeout		=> [ 1152,                     		3 ],
   },

   #
   # Refresh Security
   #
   RefreshSecurity =>
   {
   },

   #
   # Re-verify security
   #
   ReverifySecurity =>
   {
   },

   #
   # AuthorityRecord (MQ v6 on distributed platforms)
   #
   AuthorityRecord =>
   {
    AuthorizationList		=> [ 1115,                       	5,		$ResponseValues{Authority} ],
    EntityName			=> [ 3068,                		4 ],
    EntityType			=> [ 1118,                		3,			$ResponseValues{EntityType} ],
    ObjectType			=> [ 1016,                		3,			$ResponseValues{ObjectType} ],
    Options			=> [ 1228,                 		3 ],
    ProfileName			=> [ 3067,                      		4 ],
    QMgrName			=> [ 2015,             			4 ],
   },

   #
   # AuthorityService (MQ v6 on distributed platforms)
   #
   AuthorityService =>
   {
    InterfaceVersion		=> [ 1263,                      		3 ],
    ServiceComponent		=> [ 3069,                      		4 ],
    UserIdSupport		=> [ 1262,                    		3 ],
   },

   #
   # Service (installable service for distributed MQ v6)
   #
   Service =>
   {
    AlterationDate		=> [ 2027,                  		4 ],
    AlterationTime		=> [ 2028,                  		4 ],
    ServiceDesc			=> [ 2078,               		4 ],
    ServiceName			=> [ 2077,               		4 ],
    ServiceType			=> [ 121,                		3,	$ResponseValues{ServiceType} ],
    StartArguments		=> [ 2080,                     		4 ],
    StartCommand		=> [ 2079,                        	4 ],
    StartMode			=> [ 139,                   		3,	$ResponseValues{ServiceStartMode} ],
    StopArguments		=> [ 2082,                    		4 ],
    StopCommand			=> [ 2081,                       	4 ],
    StderrDestination		=> [ 2084,                     		4 ],
    StdoutDestination		=> [ 2083,                     		4 ],
   },

   #
   # Channel Listener (new with V6)
   #
   Listener =>
   {
    AlterationDate		=> [ 2027                   ,		4 ],
    AlterationTime		=> [ 2028                   ,		4 ],
    Adapter			=> [ 1519,            			3 ],
    Backlog			=> [ 1602,            			3 ],
    Commands			=> [ 1520,                  		3 ],
    IPAddress			=> [ 3552,               		4 ],
    ListenerDesc		=> [ 3555,                  		4 ],
    ListenerName		=> [ 3554,                  		4 ],
    LocalName			=> [ 3521,               		4 ],
    NetBiosNames		=> [ 1513,               		3 ],
    Port			=> [ 1522,         			3 ],
    Sessions			=> [ 1518,                  		3 ],
    Socket			=> [ 1521,           			3 ],
    StartMode			=> [ 1601,                     		3, $ResponseValues{ListenerStartMode} ],
    TPName			=> [ 3504,            			4 ],
    TransportType		=> [ 1501,                       	3, $ResponseValues{ListenerTransportType} ],
   },

   ListenerStatus =>
   {
    Adapter			=> [ 1519,            			3 ],
    Backlog			=> [ 1602,            			3 ],
    Commands			=> [ 1520,                  		3 ],
    IPAddress			=> [ 3552,               		4 ],
    ListenerDesc		=> [ 3555,                  		4 ],
    ListenerName		=> [ 3554,                  		4 ],
    LocalName			=> [ 3521,               		4 ],
    NetBiosNames		=> [ 1513,               		3 ],
    Port			=> [ 1522,         			3 ],
    ProcessId			=> [ 1024,               		3 ],
    Sessions			=> [ 1518,                  		3 ],
    Socket			=> [ 1521,           			3 ],
    StartDate			=> [ 3556,                        	4 ],
    StartMode			=> [ 1601,                     		3, $ResponseValues{ListenerStartMode} ],
    StartTime			=> [ 3557,                        	4 ],
    Status			=> [ 1599,                    		3, $ResponseValues{ListenerStatus} ],
    TPName			=> [ 3504,            			4 ],
    TransportType		=> [ 1501,                       	3, $ResponseValues{ListenerTransportType} ],
   },

   #
   # Service Status (installable service for distributed MQ v6)
   #
   ServiceStatus =>
   {
    ProcessId			=> [ 1024,               		3 ],
    ServiceDesc			=> [ 2078,               		4 ],
    ServiceName			=> [ 2077,               		4 ],
    ServiceType			=> [ 121,                		3,		$ResponseValues{ServiceType} ],
    StartArguments		=> [ 2080,                     		4 ],
    StartCommand		=> [ 2079,                        	4 ],
    StartDate			=> [ 3144,                       	4 ],
    StartMode			=> [ 139,                   		3,		$ResponseValues{ServiceStartMode} ],
    StartTime			=> [ 3145,                       	4 ],
    Status			=> [ 1260,                   		3,		$ResponseValues{ServiceStatus} ],
    StopArguments		=> [ 2082,                    		4 ],
    StopCommand			=> [ 2081,                       	4 ],
    StderrDestination		=> [ 2084,                     		4 ],
    StdoutDestination		=> [ 2083,                     		4 ],
   },

   #
   # Subscription for MQ v7
   #
   Subscription =>
   {
    AlterationDate		=> [ 2027,                  		4 ],
    AlterationTime		=> [ 2028,                  		4 ],
    CreationDate		=> [ 2004,                		4 ],
    CreationTime		=> [ 2005,                		4 ],
    Destination			=> [ 3154,                		4 ],
    DestinationClass		=> [ 1273,                      		3,		$ResponseValues{DestinationClass} ],
    DestinationCorrelId		=> [ 7015,                          	9                   ],
    DestinationQueueManager	=> [ 3153,                      		4 ],
    Durable			=> [ 1274,                         	3,		$ResponseValues{Durable} ],
    Expiry			=> [ 1244,           			3 ],
    PublishPriority		=> [ 1283,                 		3,		$ResponseValues{PublishPriority} ],
    PublishSubscribeProperties	=> [ 1271,                      		3,		$ResponseValues{PubSubProperties} ],
    PublishedAccountingToken	=> [ 7010,                     		9                   ],
    PublishedApplicationIdentifier => [ 3135,                       	4 ],
    RequestOnly			=> [ 1280,                 		3,		$ResponseValues{RequestOnly} ],
    Selector			=> [ 3160,                 		4 ],
    SelectorType		=> [ 1321,                  		3, 	$ResponseValues{SelectorType} ],
    SubId			=> [ 7016,           			9                   ],
    SubName			=> [ 3152,             			4 ],
    SubscriptionLevel		=> [ 1307,              			3 ],
    SubscriptionScope		=> [ 1275,                       	3,		$ResponseValues{SubscriptionScope} ],
    SubscriptionType		=> [ 1289,             			3,		$ResponseValues{SubscriptionType} ],
    SubscriptionUser		=> [ 3156,                		4 ],
    TopicName			=> [ 2092,             			4 ],
    TopicObject			=> [ 3031,          			4 ],
    TopicString			=> [ 2094,               		4 ],
    UserData			=> [ 3159,                  		4 ],
    VariableUser		=> [ 1277,                     		3,		$ResponseValues{VariableUser} ],
    WildcardSchema		=> [ 1288,                    		3,		$ResponseValues{WildcardSchema} ],
   },

   #
   # Subscription Status for MQ v7
   #
# LastPublishDate/Time seems to be related to topic.
   SubscriptionStatus =>
   {
    ActiveConnection		=> [ 7006,                  		9                   ],
    Durable			=> [ 1274,                         	3,		$ResponseValues{Durable} ],
    LastMessageDate		=> [ 3168,                  		4 ],
    LastMessageTime		=> [ 3167,                  		4 ],
#    LastPublishDate		=> [ 3161,                  		4 ],
#    LastPublishTime		=> [ 3162,                  		4 ],
    NumberOfMessages		=> [ 1290,                  		3 ],
    ResumeDate			=> [ 2098,              			4 ],
    ResumeTime			=> [ 2099,              			4 ],
    SubId			=> [ 7016,           			9                   ],
    SubName			=> [ 3152,             			4 ],
    SubscriptionUser		=> [ 3156,                		4 ],
    SubType			=> [ 1289,             			3,		$ResponseValues{SubscriptionType} ],
   },

   #
   # PubSubStatus
   #
   PubSubStatus =>
   {
    QueueManagerName		=> [ 2015,             			4 ],
    Type			=> [ 1314,                   		3,		$ResponseValues{PubSubStatusType} ],
    Status			=> [ 1311,                  		3,		$ResponseValues{PubSubStatus} ],
   },
   #
   # Pub/Sub Topic for MQ v7
   #
   Topic =>
   {
    AlterationDate		=> [ 2027,                  		4 ],
    AlterationTime		=> [ 2028,                  		4 ],
    ClusterName			=> [ 2029,               		4 ],
    ComminfoName		=> [ 2110,                 		4 ],
    Custom			=> [ 2119,         			3 ],
    DefPersistence		=> [ 185,                         	3,		$ResponseValues{TopicDefPersistence} ],
    DefPriority			=> [ 6,                  		3 ],
    DefPutResponse		=> [ 184,                         	3,		$ResponseValues{DefPutResponse} ],
    DurableModelQName		=> [ 2096,                  		4 ],
    DurableSubscriptions	=> [ 175,               			3,		$ResponseValues{TopicDurableSubscriptions} ],
    InhibitPublications		=> [ 181,               			3,		$ResponseValues{InhibitPublications} ],
    InhibitSubscriptions	=> [ 182,               			3,		$ResponseValues{InhibitSubscriptions} ],
    NonDurableModelQName	=> [ 2097,                      		4 ],
    NonPersistentMsgDelivery	=> [ 196,                		3,		$ResponseValues{MsgDelivery} ],
    PersistentMsgDelivery	=> [ 195,               			3,		$ResponseValues{MsgDelivery} ],
    ProxySubscriptions		=> [ 199,             			3,		$ResponseValues{ProxySubscriptions} ],
    PublicationScope		=> [ 219,             			3,		$ResponseValues{PubSubScope} ],
    QMgrName			=> [ 2015,             			4 ],
    QSGDisposition		=> [ 63,             			3,		$ResponseValues{QSGDisposition} ],
    SubscriptionScope		=> [ 218,             			3,		$ResponseValues{PubSubScope} ],
    TopicDesc			=> [ 2093,             			4 ],
    TopicName			=> [ 2092,             			4 ],
    TopicNames			=> [ 3151,                		6 ],
    TopicString			=> [ 2094,               		4 ],
    TopicType			=> [ 208,              			3,			$ResponseValues{TopicType}],
    UseDLQ			=> [ 234,                     		3, 	$ResponseValues{TopicUseDLQ} ],
    WildcardOperation		=> [ 216,                      		3,		$ResponseValues{WildcardOperation} ],
   },

   #
   # Pub/Sub Topic Status for MQ v7
   #
   TopicStatus =>
   {
    ActiveConnection		=> [ 7006,                  		9                   ],
    AdminTopicName		=> [ 2105,                   		4 ],
    ClusterName			=> [ 2029,               		4 ],
    DefPriority			=> [ 6,                  		3 ],
    DefPersistence		=> [ 185,                         	3,		$ResponseValues{TopicDefPersistence}  ],
    DefPutResponse		=> [ 184,                         	3,		$ResponseValues{DefPutResponse} ],
    DurableModelQName		=> [ 2096,                  		4 ],
    Durable			=> [ 1274,                         	3,		$ResponseValues{Durable} ],
    DurableSubscriptions	=> [ 175,               			3,		$ResponseValues{TopicStatusDurableSubscriptions} ],
    InhibitPublications		=> [ 181,               			3,		$ResponseValues{InhibitPublications} ],
    InhibitSubscriptions	=> [ 182,               			3,		$ResponseValues{InhibitSubscriptions} ],
    LastMessageDate		=> [ 3168,                  		4 ],
    LastMessageTime		=> [ 3167,                  		4 ],
    LastPublishDate		=> [ 3161,                  		4 ],
    LastPublishTime		=> [ 3162,                  		4 ],
    NonDurableModelQName	=> [ 2097,                      		4 ],
    NonPersistentMsgDelivery	=> [ 196,                		3,		$ResponseValues{MsgDelivery} ],
    NumberOfMessages		=> [ 1290,                  		3 ],
    NumberOfPublishes		=> [ 215,             			3 ],
    PersistentMsgDelivery	=> [ 195,               			3,		$ResponseValues{MsgDelivery} ],
    PublicationScope		=> [ 219,             			3,		$ResponseValues{PubSubScope} ],
    PublishCount		=> [ 215,             			3 ],
    ResumeDate			=> [ 2098,              			4 ],
    ResumeTime			=> [ 2099,              			4 ],
    RetainedPublication		=> [ 1300,                         	3,		$ResponseValues{RetainedPublication} ],
    SubscriptionCount		=> [ 204,             			3 ],
    SubId			=> [ 7016,           			9                   ],
    SubscriptionUserId		=> [ 3156,                		4 ],
    SubscriptionScope		=> [ 218,             			3,		$ResponseValues{PubSubScope} ],
    SubscriptionType		=> [ 1289,             			3,		$ResponseValues{SubscriptionType} ],
    TopicString			=> [ 2094,               		4 ],
    UseDLQ			=> [ 234,                     		3, 	$ResponseValues{TopicUseDLQ} ],
   },

   #
   # Comminfo in 7.1
   #
   Comminfo =>
   {
    AlterationDate		=> [ 2027,                  		3 ],
    AlterationTime		=> [ 2028,                  		3 ],
    ComminfoName                => [ 2110,                               4 ],
    Bridge                      => [ 233,                                3 ],
    CodedCharSetId              => [ 2,                                  3,		$ResponseValues{ComminfoCCSID} ],
    CommEvent                   => [ 232,                                3,         $ResponseValues{CommEvent} ],
    ComminfoDesc                => [ 2111,                               4 ],
    Encoding                    => [ 1243,                               3,         $ResponseValues{Encoding} ],
    GrpAddress                  => [ 3562,                               4 ],
    MonitorInterval             => [ 81,                                 3 ],
    MsgHistory                  => [ 1625,                               3 ],
    MulticastHeartbeat          => [ 1628,                               3 ],
    MulticastPropControl        => [ 1626,                               3,         $ResponseValues{MulticastPropControl} ],
    NewSubHistory               => [ 1627,                               3,         $ResponseValues{NewSubHistory}
 ],
    PortNumber                  => [ 1522,                               3 ],
    ComminfoType                => [ 223,                                3,         $ResponseValues{ComminfoType}
],
   },

   #
   # InquireLog for z/OS
   #
   Log =>
   {
    DeallocateInterval		=> [ 1176,                          	3 ],
    DualActive			=> [ 1183,                     		3 ],
    DualArchive			=> [ 1184,                      		3 ],
    DualBSDS			=> [ 1185,                   		3 ],
    InputBufferSize		=> [ 1179,                        	3 ],
    LogArchive			=> [ 1182,                 		3 ],
    LogCompression		=> [ 1322,                    		3, 	$ResponseValues{LogCompression} ],
    MaxArchiveLog		=> [ 1177,                     		3 ],
    MaxReadTapeUnits		=> [ 1178,                        	3 ],
    OutputBufferCount		=> [ 1181,                          	3 ],
    OutputBufferSize		=> [ 1180,                         	3 ],

    DataSetName			=> [ 3059,                  		4 ],
    FullLogs			=> [ 1221,                   		3 ],
    LogCopyNumber		=> [ 1216,                  		3 ],
    LogRBA			=> [ 3122,                 		4 ],
    LogSuspend			=> [ 1218,                     		3 ],
    LogUsed			=> [ 1217,                  		3 ],
    OffLoadStatus		=> [ 1219,                        	3,		$ResponseValues{OffLoadStatus} ],
    QMgrStartDate		=> [ 3120,                    		4 ],
    QMgrStartRBA		=> [ 3121,                   		4 ],
    QMgrStartTime		=> [ 3119,                    		4 ],
    TotalLogs			=> [ 1220,                    		3 ],
   },

   #
   # Authority is a Morgan Stanley extension
   #
   MorganAuthority =>
   {
    ObjectType			=> [ 1000,               		3,		$ResponseValues{ObjectType} ],
    ObjectName			=> [ 3000,               		4 ],

    EntityType			=> [ 1001,               		3,		$ResponseValues{MorganEntityType} ],
    EntityName			=> [ 3001,               		4 ],

    ExpiresAt                   => [ 4000,                               23 ],
    ExpiresAfter                => [ 4001,                               3 ],

    Connect			=> [ 1011,                		3 ],
    Browse			=> [ 1012,               		3 ],
    Input			=> [ 1013,              			3 ],
    Output			=> [ 1014,               		3 ],
    Inquire			=> [ 1015,                		3 ],
    Set				=> [ 1016,            			3 ],
    PassId			=> [ 1017,               		3 ],
    PassAll			=> [ 1018,                		3 ],
    SetId			=> [ 1019,              			3 ],
    SetAll			=> [ 1020,               		3 ],
    AlternateUser		=> [ 1021,                      		3 ],
    Create			=> [ 1022,               		3 ],
    Delete			=> [ 1023,               		3 ],
    Display			=> [ 1024,                		3 ],
    Change			=> [ 1025,               		3 ],

    Create			=> [ 1022,               		3 ],

    Clear			=> [ 1026,              			3 ],
    Authorize			=> [ 1027,                  		3 ],
    StartStop			=> [ 1028,                   		3 ],
    DisplayStatus		=> [ 1029,                       	3 ],
    ResolveReset		=> [ 1030,                      		3 ],
    Ping			=> [ 1031,             			3 ],

    AllAdmin			=> [ 1050,                 		3 ],
    AllMQI			=> [ 1051,               		3 ],
    All				=> [ 1052,            			3 ],
   },

  );

1;
