#
# WARNING: This file is automatically generated.
# Any changes made here will be mercilessly lost.
#
# You have been warned, infidel.
#
# P.S. For the real source to this file, see:
#
#    ..../src/pre.in/MQSeries/Constants/ReasonText.in
#
# and for the evil hackery used to generate this, see:
#
#    ..../src/util/flatten_macros
#
# (c) 1999-2012 Morgan Stanley & Co. Incorporated
# See ..../src/LICENSE for terms of distribution.
#
package MQSeries::Constants;

%ReasonText =
  (
   3091                              => "Action value not valid.",
   4009                              => "Allocation failed.",
   3166                              => "Alloc fast timer error.",
   3164                              => "Alloc retry error.",
   3165                              => "Alloc slow timer error.",
   3157                              => "Already joined.",
   4005                              => "Attribute value not valid.",
   3213                              => "Attr value fixed.",
   3171                              => "Auth value error.",
   3172                              => "Auth value missing.",
   3356                              => "Backlog out of range.",
   4086                              => "Batch interval not valid.",
   4087                              => "Batch interval parameter not allowed for this channel type.",
   3037                              => "Batch size not valid.",
   4024                              => "Bind failed.",
   3094                              => "Broker command failed.",
   3070                              => "Broker deleted.",
   3049                              => "Coded character-set identifier error.",
   4068                              => "Cell directory is not available.",
   3267                              => "Cfbf filter val len err.",
   3264                              => "Cfbf length error.",
   3266                              => "Cfbf operator error.",
   3265                              => "Cfbf parm id error.",
   3254                              => "Cfbs duplicate parm.",
   3255                              => "Cfbs length error.",
   3256                              => "Cfbs parm id error.",
   3257                              => "Cfbs string length err.",
   3352                              => "Cfconlos checks failed.",
   3258                              => "CFGR length error.",
   3259                              => "CFGR parm count error.",
   3240                              => "CFGR parm id error.",
   3007                              => "Command identifier not valid.",
   3005                              => "Control option not valid.",
   3002                              => "Structure length not valid.",
   3004                              => "Message sequence number not valid.",
   3006                              => "Parameter count not valid.",
   3001                              => "Type not valid.",
   3003                              => "Structure version number is not valid.",
   3241                              => "Cfif length error.",
   3242                              => "Cfif operator error.",
   3243                              => "Cfif parm id error.",
   3027                              => "Count of parameter values not valid.",
   3026                              => "Duplicate parameter.",
   3028                              => "Structure length not valid.",
   3047                              => "Parameter identifier is not valid.",
   3017                              => "Duplicate parameter.",
   3009                              => "Structure length not valid.",
   3014                              => "Parameter identifier is not valid.",
   3244                              => "CFSF filter val len err.",
   3245                              => "CFSF length error.",
   3246                              => "CFSF operator error.",
   3247                              => "CFSF parm id error.",
   3068                              => "Name count value not valid.",
   3066                              => "Duplicate parameter.",
   3024                              => "Cfsl length error.",
   3033                              => "Cfsl parm id error.",
   3069                              => "String length not valid.",
   3067                              => "Total string length error.",
   3095                              => "Conflicting parameters.",
   3018                              => "Duplicate parameter.",
   3010                              => "Structure length not valid.",
   3015                              => "Parameter identifier is not valid.",
   3011                              => "String length not valid.",
   3351                              => "CF struc already failed.",
   3236                              => "CF struc error.",
   4079                              => "Channel automatic definition error.",
   4081                              => "Channel automatic definition event error.",
   4082                              => "Channel automatic definition event parameter not allowed for this channel type.",
   4083                              => "Channel automatic definition exit name error.",
   4084                              => "Channel automatic definition exit parameter not allowed for this channel type.",
   4080                              => "Channel automatic definition parameter not allowed for this channel type.",
   4042                              => "Channel already exists.",
   4090                              => "Channel closed.",
   4038                              => "Channel disabled.",
   3235                              => "Channel error.",
   4025                              => "Channel in-doubt.",
   3218                              => "Channel initiator error.",
   4031                              => "Channel in use.",
   4044                              => "Channel name error.",
   4064                              => "Channel not active.",
   4032                              => "Channel not found.",
   3354                              => "Channel not started.",
   3062                              => "Channel table value not valid.",
   3034                              => "Channel type not valid.",
   3327                              => "Chlauth action error.",
   3337                              => "Chlauth already exists.",
   3348                              => "Chlauth clntuser error.",
   3357                              => "Chlauth disabled.",
   3344                              => "Chlauth max exceeded.",
   3349                              => "Chlauth name error.",
   3338                              => "Chlauth not found.",
   3350                              => "Chlauth runcheck error.",
   3326                              => "Chlauth type error.",
   3335                              => "Chlauth usersrc error.",
   3341                              => "Chlauth warn error.",
   3064                              => "Channel instance type not valid.",
   3065                              => "Channel status not found.",
   3168                              => "Chl system not active.",
   3323                              => "Client id error.",
   3322                              => "Client id not found.",
   3088                              => "ClusterName and ClusterNamelist attributes conflict.",
   3090                              => "Cluster queue cannot be a transmission queue.",
   3008                              => "Command failed.",
   3204                              => "Command inhibited.",
   3230                              => "Command length error.",
   3222                              => "Command level conflict.",
   3231                              => "Command origin error.",
   3226                              => "Command reply error.",
   3225                              => "Command scope error.",
   4040                              => "Commit failed.",
   3092                              => "Library for requested communications protocol could not be loaded.",
   3320                              => "Comm info type error.",
   4011                              => "Configuration error.",
   4017                              => "Connection closed.",
   3174                              => "Connection id error.",
   4012                              => "Connection refused.",
   4062                              => "Error in connection name parameter.",
   3260                              => "Conn not stopped.",
   3080                              => "Correl id error.",
   3355                              => "Custom error.",
   3052                              => "Data conversion value not valid.",
   4043                              => "Data too large.",
   3269                              => "Def xmit queue clus error.",
   3087                              => "Del options error.",
   3316                              => "Dest name error.",
   3038                              => "Disconnection interval not valid.",
   4054                              => "Disconnection interval not allowed for this channel type.",
   3163                              => "Disc retry error.",
   3211                              => "Disposition conflict.",
   3078                              => "Duplicate identity.",
   3152                              => "Duplicate subscription.",
   3314                              => "Durability not allowed.",
   4067                              => "Dynamic queue scope error.",
   3050                              => "Encoding error.",
   3329                              => "Encryption alg error.",
   3169                              => "Entity name missing.",
   4013                              => "Invalid connection name.",
   3054                              => "Escape type not valid.",
   3224                              => "Events disabled.",
   3162                              => "File not available.",
   3150                              => "Content based filter expression not valid.",
   3012                              => "Force value not valid.",
   3227                              => "Function restricted.",
   3319                              => "Groupur checks failed.",
   4077                              => "Heartbeat interval not valid.",
   4078                              => "Heartbeat interval parameter not allowed for this channel type.",
   3315                              => "Hobj error.",
   4010                              => "Remote system not available.",
   3079                              => "Incorrect queue.",
   3075                              => "Incorrect stream.",
   3053                              => "In-doubt value not valid.",
   3317                              => "Invalid destination.",
   3345                              => "Ipaddr error.",
   3343                              => "Ipaddr range conflict.",
   3346                              => "Ipaddr range error.",
   4060                              => "Keepalive interval not valid.",
   4003                              => "New and existing objects have different type.",
   3232                              => "Listener conflict.",
   4020                              => "Listener not started.",
   3249                              => "Listener running.",
   3233                              => "Listener started.",
   3268                              => "Listener still active.",
   3234                              => "Listener stopped.",
   3175                              => "Log type error.",
   3041                              => "Long retry count not valid.",
   4057                              => "Long retry parameter not allowed for this channel type.",
   3042                              => "Long timer not valid.",
   4058                              => "Long timer parameter not allowed for this channel type.",
   3250                              => "Lstr status not found.",
   3306                              => "Max instances error.",
   3307                              => "Max insts per clnt err.",
   3044                              => "Maximum message length not valid.",
   4047                              => "Message channel agent name error.",
   4053                              => "Message channel agent name not allowed for this channel type.",
   3063                              => "Message channel agent type not valid.",
   3023                              => "Format not valid.",
   4061                              => "Connection name parameter required but missing.",
   3029                              => "Mode value not valid.",
   4026                              => "MQCONN call failed.",
   4028                              => "MQGET call failed.",
   4036                              => "MQINQ call failed.",
   4027                              => "MQOPEN call failed.",
   4029                              => "MQPUT call failed.",
   4063                              => "MQSET call failed.",
   4069                              => "Message retry count not valid.",
   4070                              => "Message-retry count parameter not allowed for this channel type.",
   4071                              => "Channel message-retry exit name error.",
   4072                              => "Message-retry exit parameter not allowed for this channel type.",
   4073                              => "Message retry interval not valid.",
   4074                              => "Message-retry interval parameter not allowed for this channel type.",
   4050                              => "Channel message exit name error.",
   3016                              => "Message length not valid.",
   3030                              => "Message sequence number not valid.",
   3048                              => "Message truncated.",
   3215                              => "Namelist error.",
   3093                              => "NetBIOS listener name not defined.",
   4088                              => "Network priority value is not valid.",
   4089                              => "Network priority parameter not allowed for this channel type.",
   3200                              => "None found.",
   3081                              => "Not authorized.",
   3073                              => "Not registered.",
   4037                              => "Queue is not a transmission queue.",
   3217                              => "No channel initiator.",
   4019                              => "Communications manager not available.",
   3077                              => "No retained msg.",
   3262                              => "No start cmd.",
   3263                              => "No stop cmd.",
   4018                              => "Not enough storage available.",
   3239                              => "No XCF partner.",
   4075                              => "Nonpersistent message speed not valid.",
   4076                              => "Nonpersistent message speed parameter not allowed for this channel type.",
   4001                              => "Object already exists.",
   3205                              => "Object being deleted.",
   3160                              => "Object in use.",
   3209                              => "Object limit exceeded.",
   4008                              => "Object name not valid.",
   3208                              => "Object name restricted.",
   4004                              => "Object is open.",
   3210                              => "Object open force.",
   3173                              => "Object type missing.",
   4002                              => "Object has wrong type.",
   3203                              => "Parm conflict.",
   3020                              => "Parameter count too big.",
   3019                              => "Parameter count too small.",
   3228                              => "Parm missing.",
   3035                              => "Parameter sequence not valid.",
   3097                              => "Parm syntax error.",
   3229                              => "Parm value error.",
   3096                              => "Path not valid.",
   3032                              => "Ping Channel command failed.",
   3031                              => "Data count not valid.",
   4030                              => "Ping error.",
   3334                              => "Policy name missing.",
   3328                              => "Policy not found.",
   3332                              => "Policy version error.",
   3324                              => "Port in use.",
   3167                              => "Port number error.",
   3170                              => "Profile name error.",
   3347                              => "Profile name missing.",
   3177                              => "Program auth failed.",
   3176                              => "Program not available.",
   3359                              => "Psclus disabled topdef.",
   3360                              => "Psclus topic exists.",
   3318                              => "Pubsub inhibited.",
   3084                              => "Pub options error.",
   3046                              => "Purge value not valid.",
   3045                              => "Put authority value not valid.",
   4059                              => "Put authority parameter not allowed for this channel type.",
   3098                              => "Pwd length error.",
   3051                              => "Queues value error.",
   3029                              => "Quiesce value not valid.",
   3021                              => "Queue already exists in cell.",
   3223                              => "Queue attr conflict.",
   3086                              => "Queue manager coded character set identifier error.",
   3074                              => "Queue mgr name error.",
   3212                              => "Queue manager not in Queue Sharing Group.",
   3076                              => "Queue name error.",
   4091                              => "Queue status not found.",
   3022                              => "Queue type not valid.",
   4007                              => "Action not valid for the queue of specified type.",
   4051                              => "Channel receive exit name error.",
   4015                              => "Received data error.",
   4016                              => "Receive failed.",
   3333                              => "Recipient dn missing.",
   3083                              => "Reg options error.",
   4035                              => "Remote queue manager terminating.",
   4034                              => "Remote queue manager not available.",
   3313                              => "Remote queue name error.",
   3025                              => "Replace value not valid.",
   3089                              => "RepositoryName and RepositoryNamelist attributes conflict.",
   3055                              => "Repos value error.",
   4095                              => "Retained not supported.",
   3303                              => "Security case conflict.",
   3202                              => "Security refresh failed.",
   3201                              => "Security switch off.",
   4049                              => "Channel security exit name error.",
   4048                              => "Channel send exit name error.",
   4014                              => "Send failed.",
   3043                              => "Sequence wrap number not valid.",
   3261                              => "Service request pending.",
   3251                              => "Service running.",
   3253                              => "Service stopped.",
   3252                              => "Serv status not found.",
   3301                              => "Sharing convs error.",
   3302                              => "Sharing convs type.",
   3039                              => "Short retry count not valid.",
   4055                              => "Short retry parameter not allowed for this channel type.",
   3040                              => "Short timer value not valid.",
   4056                              => "Short timer parameter not allowed for this channel type.",
   3330                              => "Signature alg error.",
   3358                              => "Smds requires dsgroup.",
   3362                              => "Socket error.",
   3325                              => "SSL alt provider reqd.",
   4092                              => "SSL cipher spec error.",
   3361                              => "SSL cipher suite error.",
   4094                              => "SSL client auth error.",
   4093                              => "SSL peer name error.",
   3207                              => "Storage class in use.",
   3071                              => "Stream error.",
   3013                              => "Structure type not valid.",
   3155                              => "Subscription in use.",
   3156                              => "Subscription locked.",
   3309                              => "Subscription point err.",
   3311                              => "Sub already exists.",
   3154                              => "Sub identity error.",
   3153                              => "Sub name error.",
   3353                              => "Suite b error.",
   4085                              => "Action suppressed by exit program.",
   4065                              => "Channel terminated by security exit.",
   3331                              => "Toleration pol error.",
   3248                              => "Too many filters.",
   3300                              => "Topicstr already exists.",
   3072                              => "Topic error.",
   3308                              => "Topic string not found.",
   3305                              => "Topic type error.",
   3238                              => "Unexpected error.",
   3085                              => "Unknown broker.",
   3161                              => "Unknown file name.",
   3312                              => "Unknown object name.",
   4006                              => "Queue manager not known.",
   4033                              => "Remote channel not known.",
   3082                              => "Unknown stream.",
   3237                              => "Unknown user id.",
   4039                              => "User exit not available.",
   3321                              => "Use client id error.",
   4041                              => "Parameter not allowed for this channel type.",
   3339                              => "Wrong chlauth action.",
   3342                              => "Wrong chlauth match.",
   3336                              => "Wrong chlauth type.",
   3340                              => "Wrong chlauth usersrc.",
   3151                              => "Wrong user.",
   3036                              => "Transmission protocol type not valid.",
   4045                              => "Transmission queue name error.",
   4052                              => "Transmission queue name not allowed for this channel type.",
   2535                              => "Action error.",
   2129                              => "Unable to load adapter connection module.",
   2133                              => "Unable to load data conversion services modules.",
   2131                              => "Adapter subsystem definition module not valid.",
   2132                              => "Unable to load adapter subsystem definition module.",
   2138                              => "Unable to load adapter disconnection module.",
   2204                              => "Adapter not available.",
   2130                              => "Unable to load adapter service module.",
   2127                              => "Insufficient storage for adapter.",
   2385                              => "Air error.",
   2001                              => "Alias base queue not a valid type.",
   2480                              => "Alias targtype changed.",
   2002                              => "Application already connected.",
   2542                              => "Already joined.",
   2435                              => "Alter sub error.",
   2103                              => "Another queue manager already connected.",
   2374                              => "API exit error.",
   2375                              => "API exit init error.",
   2183                              => "Unable to load API crossing exit.",
   2182                              => "API exit not found.",
   2376                              => "API exit term error.",
   900                               => "Lowest value for an application-defined reason code returned by a data-conversion exit.",
   999                               => "Highest value for application-defined reason code returned by a data-conversion exit.",
   2157                              => "Primary and home ASIDs differ.",
   2529                              => "Async UOW conflict.",
   2530                              => "Async XA conflict.",
   6104                              => "Attribute locked.",
   2387                              => "Auth info conn name error.",
   2383                              => "Auth info rec count error.",
   2384                              => "Auth info rec error.",
   2386                              => "Auth info type error.",
   2003                              => "Unit of work encountered fatal error or backed out.",
   2362                              => "Backout threshold reached.",
   2303                              => "Data could not be converted into a bag.",
   2326                              => "Bag has wrong type for intended use.",
   6111                              => "Binary data length error.",
   2489                              => "BMHO error.",
   2134                              => "Begin-options structure not valid.",
   2125                              => "Bridge started.",
   2126                              => "Bridge stopped.",
   2004                              => "Buffer parameter not valid.",
   2005                              => "Buffer length parameter not valid.",
   6112                              => "Buffer not automatic.",
   2487                              => "Callback link error.",
   2448                              => "Callback not registered.",
   2486                              => "Callback routine error.",
   2483                              => "Callback type error.",
   2549                              => "Call interrupted.",
   2219                              => "MQI call reentered before previous call complete.",
   2444                              => "Cbd error.",
   2484                              => "Cbd options error.",
   2576                              => "Cd array error.",
   2277                              => "Channel definition not valid.",
   2422                              => "Cfbf error.",
   2395                              => "Cfbs error.",
   2416                              => "CFGR error.",
   2235                              => "PCF header structure not valid.",
   2414                              => "Cfif error.",
   2236                              => "PCF integer list parameter structure not valid.",
   2237                              => "PCF integer parameter structure not valid.",
   2415                              => "CFSF error.",
   2238                              => "PCF string list parameter structure not valid.",
   2239                              => "PCF string parameter structure not valid.",
   2345                              => "CF not available.",
   2348                              => "CF struc auth failed.",
   2349                              => "CF struc error.",
   2373                              => "CF struc failed.",
   2346                              => "CF struc in use.",
   2347                              => "CF struc list hdr in use.",
   2295                              => "Channel activated.",
   2234                              => "Automatic channel definition failed.",
   2233                              => "Automatic channel definition succeeded.",
   2577                              => "Channel blocked.",
   2578                              => "Channel blocked warning.",
   2539                              => "Channel config error.",
   2284                              => "Channel conversion error.",
   2296                              => "Channel cannot be activated.",
   2537                              => "Channel not available.",
   2371                              => "Channel SSL error.",
   2552                              => "Channel SSL warning.",
   2282                              => "Channel started.",
   2283                              => "Channel stopped.",
   2279                              => "Channel stopped by user.",
   2007                              => "Character attributes string not valid.",
   2008                              => "Not enough space allowed for character attributes.",
   2006                              => "Length of character attributes not valid.",
   2340                              => "Char conversion error.",
   2187                              => "Requested function not supported by CICS bridge.",
   2140                              => "Wait request rejected by CICS.",
   2591                              => "Cipher spec not suite b.",
   2423                              => "Client channel conflict.",
   2278                              => "Client connection fields not valid.",
   2407                              => "Client exit error.",
   2406                              => "Client exit load error.",
   2266                              => "Cluster workload exit failed.",
   2267                              => "Unable to load cluster workload exit.",
   2268                              => "Put calls inhibited for all queues in cluster.",
   2189                              => "Cluster name resolution failed.",
   2269                              => "Cluster resource error.",
   2322                              => "Command server not available.",
   2461                              => "Cmho error.",
   2139                              => "Connect-options structure not valid.",
   2330                              => "Coded character set identifier parameter not valid.",
   2106                              => "COD report option not valid for XCF queue.",
   2412                              => "Command MQSC.",
   2413                              => "Command PCF.",
   2300                              => "Command type not valid.",
   2558                              => "Comminfo error.",
   2368                              => "Change Object",
   2367                              => "Create Object",
   2369                              => "Delete Object",
   2370                              => "Refresh Object",
   2009                              => "Connection to queue manager lost.",
   2273                              => "Error processing MQCONN call.",
   2217                              => "Not authorized for connection.",
   2568                              => "Connection not available.",
   2202                              => "Connection quiescing.",
   2528                              => "Connection stopped.",
   2203                              => "Connection shutting down.",
   2521                              => "Connection suspended.",
   2160                              => "Connection identifier already in use.",
   2271                              => "Conn tag in use.",
   2344                              => "Conn tag not released.",
   2350                              => "Conn tag not usable.",
   2554                              => "Content error.",
   2097                              => "Queue handle referred to does not save context.",
   2098                              => "Context not available for queue handle referred to.",
   6121                              => "Context object not valid.",
   6122                              => "Context open error.",
   2120                              => "Converted data too big for buffer.",
   2190                              => "Converted string too big for field.",
   2207                              => "Correlation-identifier error.",
   2382                              => "Crypto hardware error.",
   2445                              => "CTLO error.",
   2357                              => "Current record error.",
   6105                              => "Cursor not valid.",
   2010                              => "Data length parameter not valid.",
   2561                              => "Data set not available.",
   6115                              => "Data truncated.",
   2342                              => "DB2 not available.",
   2150                              => "DBCS string not valid.",
   2559                              => "Def syncpoint inhibited.",
   2198                              => "Default transmission queue not local.",
   2199                              => "Default transmission queue usage error.",
   2533                              => "Dest class not alterable.",
   2263                              => "Destination environment data error.",
   2264                              => "Destination name data error.",
   2135                              => "Distribution header structure not valid.",
   6126                              => "Distribution list empty.",
   2141                              => "Dead letter header structure not valid.",
   2462                              => "Dmho error.",
   2481                              => "DMPO error.",
   2514                              => "Duplicate group sub.",
   2163                              => "Recovery coordinator already exists.",
   2436                              => "Durability not allowed.",
   2509                              => "Durability not alterable.",
   2011                              => "Name of dynamic queue not valid.",
   6106                              => "Encoding error.",
   2308                              => "Encoding not supported.",
   2012                              => "Call not valid in environment.",
   2420                              => "Eph error.",
   2588                              => "Exit props not supported.",
   2377                              => "Exit reason error.",
   2013                              => "Expiry time not valid.",
   2590                              => "Fastpath not available.",
   2014                              => "Feedback code not valid.",
   2216                              => "File not audited.",
   2208                              => "File-system error.",
   2418                              => "Filter operator error.",
   2110                              => "Message format not valid.",
   2317                              => "Format not supported.",
   2281                              => "Function identifier not valid for service.",
   2298                              => "Function not supported.",
   2494                              => "Get enabled.",
   2016                              => "Gets inhibited for the queue.",
   2351                              => "Global UOW conflict.",
   2186                              => "Get-message options structure not valid.",
   2562                              => "Grouping not allowed.",
   2515                              => "Grouping not alterable.",
   2563                              => "Group address error.",
   2258                              => "Group identifier not valid.",
   2353                              => "Handle in use for UOW.",
   2017                              => "No more handles available.",
   2320                              => "Bag handle not valid.",
   2280                              => "Configuration handle not valid.",
   2500                              => "Hconn async active.",
   2018                              => "Connection handle not valid.",
   2142                              => "MQ header structure not valid.",
   2460                              => "Hmsg error.",
   2587                              => "Hmsg not available.",
   2019                              => "Object handle not valid.",
   2517                              => "Hobj quiesced.",
   2518                              => "Hobj quiesced no msgs.",
   2538                              => "Host not available.",
   2434                              => "Identity mismatch.",
   2148                              => "IMS information header structure not valid.",
   2464                              => "IMPO error.",
   2241                              => "Message group not complete.",
   2242                              => "Logical message not complete.",
   2259                              => "Inconsistent browse specification.",
   2243                              => "Message segments have differing CCSIDs.",
   2244                              => "Message segments have differing encodings.",
   6119                              => "Inconsistent format.",
   2313                              => "Data type of item differs from previous occurrence of selector.",
   6120                              => "Inconsistent object state.",
   6127                              => "Inconsistent open options.",
   2185                              => "Inconsistent persistence specification.",
   2245                              => "Inconsistent unit-of-work specification.",
   2314                              => "Index not valid.",
   2306                              => "Index not present.",
   2020                              => "Value for inhibit-get or inhibit-put queue attribute not valid.",
   2286                              => "Initialization failed for an undefined reason.",
   2324                              => "Command code is not a recognized inquiry command.",
   2583                              => "Installation mismatch.",
   2589                              => "Installation missing.",
   6113                              => "Insufficient buffer.",
   6114                              => "Insufficient data.",
   2023                              => "Integer attributes array not valid.",
   2021                              => "Count of integer attributes not valid.",
   2022                              => "Not enough space allowed for integer attributes.",
   2522                              => "Invalid destination.",
   2246                              => "Message under cursor not valid for retrieval.",
   2523                              => "Invalid subscription.",
   2316                              => "ItemCount parameter not valid.",
   2327                              => "ItemType parameter not valid.",
   2319                              => "ItemValue parameter not valid.",
   2364                              => "JMS format error.",
   2397                              => "JSSE error.",
   2381                              => "Key repository error.",
   2390                              => "LDAP password error.",
   2388                              => "LDAP user name error.",
   2389                              => "LDAP user name length err.",
   2352                              => "Local UOW conflict.",
   2411                              => "Logger status.",
   2541                              => "Looping publication.",
   2247                              => "Match options not valid.",
   2025                              => "Maximum number of connections reached.",
   2485                              => "Max msg length error.",
   2571                              => "Mcast pub status.",
   2572                              => "Mcast sub status.",
   2248                              => "Message descriptor extension not valid.",
   2026                              => "Message descriptor not valid.",
   2501                              => "Mhbo error.",
   2027                              => "Missing reply-to queue.",
   2332                              => "Message data does not begin with MQWIH.",
   2498                              => "Mixed content not allowed.",
   2497                              => "Module entry not found.",
   2496                              => "Module invalid.",
   2495                              => "Module not found.",
   2249                              => "Message flags not valid.",
   2532                              => "Msg handle copy failure.",
   2499                              => "Msg handle in use.",
   2206                              => "Message-identifier error.",
   2200                              => "Msg marked browse co op.",
   2417                              => "Msg not allowed in group.",
   2363                              => "Msg not matched.",
   2250                              => "Message sequence number not valid.",
   2331                              => "Use of message token not valid.",
   2218                              => "Message length greater than maximum for channel.",
   2030                              => "Message length greater than maximum for queue.",
   2031                              => "Message length greater than maximum for queue manager.",
   2029                              => "Message type in message descriptor not valid.",
   2564                              => "Multicast config error.",
   2565                              => "Multicast interface error.",
   2567                              => "Multicast internal error.",
   2560                              => "Multicast only.",
   2566                              => "Multicast send error.",
   2301                              => "Multiple instances of system data item not valid.",
   2136                              => "Multiple reason codes returned.",
   2201                              => "Name in use.",
   2194                              => "Object name not valid for object type.",
   6117                              => "Length is negative.",
   6118                              => "Negative offset.",
   2325                              => "Input bag contains one or more nested bags.",
   2419                              => "Nested selector error.",
   2358                              => "Next offset error.",
   2361                              => "Next record error.",
   0                                 => "No reason to report.",
   2035                              => "Not authorized for access.",
   6124                              => "Not connected.",
   2119                              => "Application message data not converted.",
   6125                              => "Not open.",
   2036                              => "Queue not open for browse.",
   2037                              => "Queue not open for input.",
   2038                              => "Queue not open for inquire.",
   2039                              => "Queue not open for output.",
   2093                              => "Queue not open for pass all context.",
   2094                              => "Queue not open for pass identity context.",
   2040                              => "Queue not open for set.",
   2095                              => "Queue not open for set all context.",
   2096                              => "Queue not open for set identity context.",
   2584                              => "Not privileged.",
   6110                              => "No buffer.",
   2446                              => "No callbacks active.",
   6109                              => "No connection reference.",
   2379                              => "No data available.",
   2270                              => "No destination queues available.",
   2121                              => "No participating resource managers registered.",
   2033                              => "No message available.",
   2209                              => "No message locked.",
   2034                              => "Browse cursor not positioned on message.",
   2359                              => "No record available.",
   2437                              => "No retained msg.",
   2428                              => "No subscription.",
   2550                              => "No subs matched.",
   6108                              => "Null pointer.",
   2100                              => "Object already exists.",
   2041                              => "Object definition changed since opened.",
   2101                              => "Object damaged.",
   2042                              => "Object already open with conflicting options.",
   2360                              => "Object level incompatible.",
   2152                              => "Object name not valid.",
   2343                              => "Object not unique.",
   2153                              => "Object queue-manager name not valid.",
   2155                              => "Object records not valid.",
   2441                              => "Object string error.",
   2043                              => "Object type not valid.",
   2553                              => "Ocsp URL error.",
   2044                              => "Object descriptor structure not valid.",
   2251                              => "Message segment offset not valid.",
   2137                              => "Object not opened successfully.",
   2488                              => "Operation error.",
   2534                              => "Operation not allowed.",
   2457                              => "Options changed.",
   2046                              => "Options not valid or not consistent.",
   2274                              => "Option not valid in environment.",
   2045                              => "Option not valid for object type.",
   2252                              => "Original length not valid.",
   2123                              => "Result of commit or back-out operation is mixed.",
   2124                              => "Result of commit operation is pending.",
   2310                              => "OutSelector parameter not valid.",
   2193                              => "Error accessing page set data set.",
   2192                              => "Page set data set full.",
   2321                              => "Parameter missing.",
   2272                              => "Partially converted.",
   2122                              => "Participating resource manager not available.",
   2372                              => "Participant not defined.",
   2149                              => "PCF structures not valid.",
   2482                              => "PD error.",
   2047                              => "Persistence not valid.",
   2048                              => "Message on a temporary dynamic queue cannot be persistent.",
   2173                              => "Put-message options structure not valid.",
   2158                              => "Put message record flags not valid.",
   2575                              => "Preconn exit error.",
   2573                              => "Preconn exit load error.",
   2574                              => "Preconn exit not found.",
   2050                              => "Message priority not valid.",
   2049                              => "Message Priority exceeds maximum value supported.",
   2586                              => "Properties disabled.",
   2478                              => "Properties too big.",
   2442                              => "Property name error.",
   2513                              => "Property name length err.",
   2465                              => "Property name too big.",
   2471                              => "Property not available.",
   2473                              => "Property type error.",
   2469                              => "Property value too big.",
   2470                              => "Prop conv not supported.",
   2492                              => "Prop name not converted.",
   2472                              => "Prop number format error.",
   2467                              => "Prop type not supported.",
   2466                              => "Prop value not converted.",
   2502                              => "Publication failure.",
   2557                              => "Publish exit error.",
   2531                              => "Pubsub inhibited.",
   2051                              => "Put calls inhibited for the queue.",
   2159                              => "Put message records not valid.",
   2479                              => "Put not retained.",
   2290                              => "Queue object already exists.",
   2052                              => "Queue has been deleted.",
   2224                              => "Queue depth high limit reached or exceeded.",
   2225                              => "Queue depth low limit reached or exceeded.",
   2053                              => "Queue already contains maximum number of messages.",
   2394                              => "Queue index type error.",
   2222                              => "Queue manager created.",
   2058                              => "Queue manager name not valid or not known.",
   2223                              => "Queue manager unavailable.",
   2059                              => "Queue manager not available for connection.",
   2161                              => "Queue manager quiescing.",
   2162                              => "Queue manager shutting down.",
   2055                              => "Queue contains one or more messages or uncommitted put or get requests.",
   2226                              => "Queue service interval high.",
   2227                              => "Queue service interval ok.",
   2056                              => "No space available on disk for queue.",
   2057                              => "Queue type not valid.",
   2229                              => "Ras property error.",
   2458                              => "Read ahead msgs.",
   2545                              => "Reconnected.",
   2544                              => "Reconnecting.",
   2548                              => "Reconnect failed.",
   2547                              => "Reconnect incompatible.",
   2546                              => "Reconnect qmid mismatch.",
   2555                              => "Reconnect queue mgr reqd.",
   2556                              => "Reconnect timed out.",
   2154                              => "Number of records present not valid.",
   6129                              => "Reference error.",
   2184                              => "Remote queue name not valid.",
   6100                              => "Reopen excl input error.",
   6101                              => "Reopen inquire error.",
   6102                              => "Reopen saved context err.",
   6103                              => "Reopen temporary queue error.",
   2061                              => "Report options in message descriptor not valid.",
   2378                              => "Reserved value error.",
   2102                              => "Insufficient system resources available.",
   2156                              => "Response records not valid.",
   2520                              => "Res object string error.",
   2525                              => "Retained msg queue error.",
   2526                              => "Retained not delivered.",
   2336                              => "Command not valid.",
   2338                              => "Duplicate parameter.",
   2334                              => "MQRFH structure not valid.",
   2421                              => "RFH format error.",
   2228                              => "RFH header field error.",
   2337                              => "Parameter not valid.",
   2339                              => "Parameter missing.",
   2527                              => "RFH restricted format err.",
   2335                              => "<TT><VAR>NameValueString</VAR></TT> field not valid.",
   2220                              => "Reference message header structure not valid.",
   2380                              => "SCO error.",
   2424                              => "Sd error.",
   2062                              => "A message is already marked.",
   2063                              => "Security error occurred.",
   2443                              => "Segmentation not allowed.",
   2365                              => "Segments not supported.",
   2253                              => "Length of data in message segment is zero.",
   2551                              => "Selection not available.",
   2519                              => "Selection string error.",
   2504                              => "Selector always false.",
   2065                              => "Count of selectors not valid.",
   2067                              => "Attribute selector not valid.",
   2516                              => "Selector invalid for type.",
   2066                              => "Count of selectors too big.",
   2524                              => "Selector not alterable.",
   2068                              => "Selector not applicable to queue type.",
   2309                              => "Selector not present in bag.",
   2318                              => "System selector not supported.",
   2305                              => "Selector occurs more than once in bag.",
   2304                              => "Selector not within valid range for call.",
   2459                              => "Selector syntax error.",
   2299                              => "Selector has wrong data type.",
   2312                              => "Selector implies a data type not valid for call.",
   2289                              => "Unexpected error occurred accessing service.",
   2285                              => "Underlying service not available.",
   2099                              => "Signal field not valid.",
   2069                              => "Signal outstanding for this handle.",
   2070                              => "No message returned (but signal request accepted).",
   2463                              => "Smpo error.",
   2211                              => "SOAP axis error.",
   2210                              => "SOAP dotnet error.",
   2212                              => "SOAP URL error.",
   2145                              => "Source buffer parameter not valid.",
   2111                              => "Source coded character set identifier not valid.",
   2113                              => "Packed-decimal encoding in message not recognized.",
   2114                              => "Floating-point encoding in message not recognized.",
   2112                              => "Source integer encoding not recognized.",
   2143                              => "Source length parameter not valid.",
   2261                              => "Source environment data error.",
   2262                              => "Source name data error.",
   2438                              => "SRO error.",
   2391                              => "SSL already initialized.",
   2570                              => "SSL alt provider required.",
   2401                              => "SSL certificate revoked.",
   2402                              => "SSL cert store error.",
   2392                              => "SSL config error.",
   2393                              => "SSL initialization error.",
   2409                              => "SSL key reset error.",
   2396                              => "SSL not allowed.",
   2399                              => "SSL peer name error.",
   2398                              => "SSL peer name mismatch.",
   2543                              => "Standby queue mgr.",
   2430                              => "Stat type error.",
   2188                              => "Call rejected by cluster-workload exit.",
   2105                              => "Storage class error.",
   2192                              => "Storage medium full.",
   2071                              => "Insufficient storage available.",
   2307                              => "String parameter not valid.",
   2323                              => "StringLength parameter not valid.",
   2311                              => "String truncated (too long for output buffer).",
   6107                              => "Struc id error.",
   6123                              => "Struc length error.",
   2426                              => "Sts error.",
   2512                              => "Sublevel not alterable.",
   2581                              => "Subscription change.",
   2579                              => "Subscription create.",
   2580                              => "Subscription delete.",
   2429                              => "Subscription in use.",
   2582                              => "Subscription refresh.",
   2432                              => "Sub already exists.",
   2503                              => "Sub inhibited.",
   2440                              => "Sub name error.",
   2431                              => "Sub user data error.",
   2592                              => "Suite b error.",
   2109                              => "Call suppressed by exit program.",
   2024                              => "No more messages can be handled within current unit of work.",
   2569                              => "Syncpoint not allowed.",
   2072                              => "Syncpoint support not available.",
   2315                              => "System bag is read-only and cannot be altered.",
   2328                              => "System bag is read-only and cannot be deleted.",
   2302                              => "System data item is read-only and cannot be altered.",
   2329                              => "System data item is read-only and cannot be deleted.",
   2146                              => "Target buffer parameter not valid.",
   2115                              => "Target coded character set identifier not valid.",
   2117                              => "Packed-decimal encoding specified by receiver not recognized.",
   2118                              => "Floating-point encoding specified by receiver not recognized.",
   2116                              => "Target integer encoding not recognized.",
   2144                              => "Target length parameter not valid.",
   2287                              => "Termination failed for an undefined reason.",
   2191                              => "Character trigger message structure not valid.",
   2265                              => "Trigger message structure not valid.",
   2510                              => "Topic not alterable.",
   2425                              => "Topic string error.",
   2075                              => "Value for trigger-control attribute not valid.",
   2076                              => "Value for trigger-depth attribute not valid.",
   2077                              => "Value for trigger-message-priority attribute not valid.",
   2078                              => "Value for trigger-type attribute not valid.",
   2120                              => "Truncated.",
   2079                              => "Truncated message returned (processing completed).",
   2080                              => "Truncated message returned (processing not completed).",
   2341                              => "UCS2 conversion error.",
   2195                              => "Unexpected error occurred.",
   2232                              => "Unit of work not started.",
   2082                              => "Unknown alias base queue.",
   2293                              => "Authorization entity unknown to service.",
   2540                              => "Unknown channel name.",
   2410                              => "Unknown component name.",
   2197                              => "Unknown default transmission queue.",
   2292                              => "Entity unknown to service.",
   2085                              => "Unknown object name.",
   2086                              => "Unknown object queue manager.",
   2288                              => "Queue name not found.",
   2294                              => "Reference object unknown.",
   2087                              => "Unknown remote queue manager.",
   2104                              => "Report option(s) in message descriptor not recognized.",
   2196                              => "Unknown transmission queue.",
   2400                              => "Unsupported cipher suite.",
   2490                              => "Unsupported property.",
   2297                              => "Unit of work canceled.",
   2408                              => "UOW committed.",
   2354                              => "UOW enlistment error.",
   2128                              => "Unit of work already started.",
   2355                              => "UOW mix not supported.",
   2255                              => "Unit of work not available for the queue manager to use.",
   2291                              => "Unable to determine the user ID.",
   2090                              => "Wait interval in MQGMO not valid.",
   2333                              => "MQWIH structure not valid.",
   2366                              => "Wrong CF level.",
   2256                              => "Wrong version of MQGMO supplied.",
   2257                              => "Wrong version of MQMD supplied.",
   6128                              => "Wrong version.",
   2356                              => "Wxp error.",
   2507                              => "Xepo error.",
   2091                              => "Transmission queue not local.",
   2092                              => "Transmission queue with wrong usage.",
   2260                              => "Transmission queue header structure not valid.",
   6130                              => "Xr not available.",
   2107                              => "MQXWAIT call canceled.",
   2108                              => "Invocation of MQXWAIT call not valid.",
   6116                              => "Zero length.",
  );

1;
