#
# WARNING: This file is automatically generated.
# Any changes made here will be mercilessly lost.
#
# You have been warned, infidel.
#
# P.S. For the real source to this file, see:
#
#    ..../src/pre.in/MQSeries/Constants/StringAttribute.in
#
# and for the evil hackery used to generate this, see:
#
#    ..../src/util/flatten_macros
#
# (c) 1999-2012 Morgan Stanley & Co. Incorporated
# See ..../src/LICENSE for terms of distribution.
#
package MQSeries::Constants;

%StringAttribute =
  (
   "AlterationDate"                     => 2027,
   "AlterationTime"                     => 2028,
   "ApplId"                             => 2001,
   "BackoutRequeueName"                 => 2019,
   "BaseQName"                          => 2002,
   "ChannelAutoDefExit"                 => 2026,
   "ClusterDate"                        => 2037,
   "ClusterName"                        => 2029,
   "ClusterNamelist"                    => 2030,
   "QMgrName"                           => 2031,
   "ClusterTime"                        => 2038,
   "ClusterWorkLoadData"                => 2034,
   "ClusterWorkLoadExit"                => 2033,
   "CommandInputQName"                  => 2003,
   "CreationDate"                       => 2004,
   "CreationTime"                       => 2005,
   "DeadLetterQName"                    => 2006,
   "DefXmitQName"                       => 2025,
   "EnvData"                            => 2007,
   "InitiationQName"                    => 2008,
   "NamelistDesc"                       => 2009,
   "NamelistName"                       => 2010,
   "Names"                              => 2020,
   "ProcessDesc"                        => 2011,
   "ProcessName "                       => 2012,
   "ProcessName"                        => 2012,
   "QDesc"                              => 2013,
   "QMgrDesc"                           => 2014,
   "QMgrIdentifier"                     => 2032,
   "QMgrName"                           => 2015,
   "QName"                              => 2016,
   "RemoteQMgrName"                     => 2017,
   "RemoteQName"                        => 2018,
   "RepositoryName"                     => 2035,
   "RepositoryNamelist"                 => 2036,
   "TriggerData"                        => 2023,
   "UserData"                           => 2021,
   "XmitQName"                          => 2024,

   "ApplType"                           => 1,
   "AuthorityEvent"                     => 47,
   "BackoutThreshold"                   => 22,
   "ChannelAutoDef"                     => 55,
   "ChannelAutoDefEvent"                => 56,
   "ClusterQType"                       => 59,
   "ClusterWorkLoadLength"              => 58,
   "CodedCharSetId"                     => 2,
   "CommandLevel"                       => 31,
   "CurrentQDepth"                      => 3,
   "DefinitionType"                     => 7,
   "DefBind"                            => 61,
   "DefInputOpenOption"                 => 4,
   "DefPersistence"                     => 5,
   "DefPriority"                        => 6,
   "DistLists"                          => 34,
   "HardenGetBackout"                   => 8,
   "HighQDepth"                         => 36,
   "InhibitEvent"                       => 48,
   "InhibitGet"                         => 9,
   "InhibitPut"                         => 10,
   "LocalEvent"                         => 49,
   "MaxHandles"                         => 11,
   "MaxMsgLength"                       => 13,
   "MaxPriority"                        => 14,
   "MaxQDepth"                          => 15,
   "MaxUncommittedMsgs"                 => 33,
   "MsgDeliverySequence",               => 16,
   "MsgDeqCount"                        => 38,
   "MsgEnqCount"                        => 37,
   "OpenInputCount"                     => 17,
   "OpenOutputCount"                    => 18,
   "PerformanceEvent"                   => 53,
   "Platform",                          => 32,
   "QDepthHighEvent"                    => 43,
   "QDepthHighLimit"                    => 40,
   "QDepthLowEvent"                     => 44,
   "QDepthLowLimit"                     => 41,
   "QDepthMaxEvent"                     => 42,
   "QServiceInterval"                   => 54,
   "QServiceIntervalEvent",             => 46,
   "QType"                              => 20,
   "RemoteEvent"                        => 50,
   "RetentionInterval"                  => 21,
   "Scope",                             => 45,
   "Shareability"                       => 23,
   "StartStopEvent"                     => 52,
   "SyncPoint"                          => 30,
   "TimeSinceReset"                     => 35,
   "TriggerControl"                     => 24,
   "TriggerDepth"                       => 29,
   "TriggerInterval"                    => 25,
   "TriggerMsgPriority"                 => 26,
   "TriggerType",                       => 28,
   "Usage",                             => 12,
  );

1;
